"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new.resolve_films_bots.film_keys_bot import Films
from ArWikiCats.new.resolve_films_bots.resolve_films_labels import _get_films_key_tyty_new

test_data = {
    "3d comics": "قصص مصورة ثلاثية الأبعاد",
    "3d film series": "سلاسل أفلام ثلاثية الأبعاد",
    "3d soap opera": "مسلسلات طويلة ثلاثية الأبعاد",
    "3d television episodes": "حلقات تلفزيونية ثلاثية الأبعاد",
    "3d television films": "أفلام تلفزيونية ثلاثية الأبعاد",
    "3d television miniseries": "مسلسلات قصيرة تلفزيونية ثلاثية الأبعاد",
    "3d television news": "أخبار تلفزيونية ثلاثية الأبعاد",
    "3d television programmes": "برامج تلفزيونية ثلاثية الأبعاد",
    "3d television programs": "برامج تلفزيونية ثلاثية الأبعاد",
    "3d television series": "مسلسلات تلفزيونية ثلاثية الأبعاد",
    "3d video games": "ألعاب فيديو ثلاثية الأبعاد",
    "3d web series": "مسلسلات ويب ثلاثية الأبعاد",
    "4d comics": "قصص مصورة رباعية الأبعاد",
    "4d film series": "سلاسل أفلام رباعية الأبعاد",
    "4d soap opera": "مسلسلات طويلة رباعية الأبعاد",
    "4d television episodes": "حلقات تلفزيونية رباعية الأبعاد",
    "4d television films": "أفلام تلفزيونية رباعية الأبعاد",
    "4d television miniseries": "مسلسلات قصيرة تلفزيونية رباعية الأبعاد",
    "4d television news": "أخبار تلفزيونية رباعية الأبعاد",
    "4d television programmes": "برامج تلفزيونية رباعية الأبعاد",
    "4d television programs": "برامج تلفزيونية رباعية الأبعاد",
    "4d television series": "مسلسلات تلفزيونية رباعية الأبعاد",
    "4d video games": "ألعاب فيديو رباعية الأبعاد",
    "4d web series": "مسلسلات ويب رباعية الأبعاد",
    "action comedy comics": "قصص مصورة حركة كوميدية",
    "action comedy film series": "سلاسل أفلام حركة كوميدية",
    "action comedy soap opera": "مسلسلات طويلة حركة كوميدية",
    "action comedy television episodes": "حلقات تلفزيونية حركة كوميدية",
    "action comedy television films": "أفلام تلفزيونية حركة كوميدية",
    "action comedy television miniseries": "مسلسلات قصيرة تلفزيونية حركة كوميدية",
    "action comedy television news": "أخبار تلفزيونية حركة كوميدية",
    "action comedy television programmes": "برامج تلفزيونية حركة كوميدية",
    "action comedy television programs": "برامج تلفزيونية حركة كوميدية",
    "action comedy television series": "مسلسلات تلفزيونية حركة كوميدية",
    "action comedy video games": "ألعاب فيديو حركة كوميدية",
    "action comedy web series": "مسلسلات ويب حركة كوميدية",
    "action comics": "قصص مصورة حركة",
    "action film series": "سلاسل أفلام حركة",
    "action films": "أفلام حركة",
    "action soap opera": "مسلسلات طويلة حركة",
    "action television episodes": "حلقات تلفزيونية حركة",
    "action television films": "أفلام تلفزيونية حركة",
    "action television miniseries": "مسلسلات قصيرة تلفزيونية حركة",
    "action television news": "أخبار تلفزيونية حركة",
    "action television programmes": "برامج تلفزيونية حركة",
    "action television programs": "برامج تلفزيونية حركة",
    "action television series": "مسلسلات تلفزيونية حركة",
    "action thriller comics": "قصص مصورة إثارة حركة",
    "action thriller film series": "سلاسل أفلام إثارة حركة",
    "action thriller soap opera": "مسلسلات طويلة إثارة حركة",
    "adventure films": "أفلام مغامرات",
    "animated films": "أفلام رسوم متحركة",
    "anime and manga characters": "شخصيات أنمي ومانغا",
    "anime films": "أفلام أنمي",
    "anthology films": "أفلام أنثولوجيا",
    "black comedy films": "أفلام كوميدية سوداء",
    "buddy films": "أفلام رفقاء",
    "comedy films": "أفلام كوميدية",
    "comics characters": "شخصيات قصص مصورة",
    "comics images": "صور قصص مصورة",
    "crime films": "أفلام جريمة",
    "dark fantasy films": "أفلام فانتازيا مظلمة",
    "documentary films": "أفلام وثائقية",
    "epic films": "أفلام ملحمية",
    "fantasy films": "أفلام فانتازيا",
    "horror films": "أفلام رعب",
    "melodrama films": "أفلام ميلودراما",
    "mystery film series": "سلاسل أفلام غموض",
    "parody films": "أفلام ساخرة",
    "police procedural films": "أفلام إجراءات الشرطة",
    "science fiction thriller films": "أفلام إثارة خيال علمي",
    "thriller films": "أفلام إثارة",
    "war films": "أفلام حربية",
}

test_data2 = {
    "3d comics": "قصص مصورة ثلاثية الأبعاد",
    "3d film series": "سلاسل أفلام ثلاثية الأبعاد",
    "3d soap opera": "مسلسلات طويلة ثلاثية الأبعاد",
    "3d television episodes": "حلقات تلفزيونية ثلاثية الأبعاد",
    "3d television films": "أفلام تلفزيونية ثلاثية الأبعاد",
    "3d television miniseries": "مسلسلات قصيرة تلفزيونية ثلاثية الأبعاد",
    "3d television news": "أخبار تلفزيونية ثلاثية الأبعاد",
    "3d television programmes": "برامج تلفزيونية ثلاثية الأبعاد",
    "3d television programs": "برامج تلفزيونية ثلاثية الأبعاد",
    "3d television series": "مسلسلات تلفزيونية ثلاثية الأبعاد",
    "3d video games": "ألعاب فيديو ثلاثية الأبعاد",
    "3d web series": "مسلسلات ويب ثلاثية الأبعاد",
    "4d comics": "قصص مصورة رباعية الأبعاد",
    "4d film series": "سلاسل أفلام رباعية الأبعاد",
    "4d soap opera": "مسلسلات طويلة رباعية الأبعاد",
    "4d television episodes": "حلقات تلفزيونية رباعية الأبعاد",
    "4d television films": "أفلام تلفزيونية رباعية الأبعاد",
    "4d television miniseries": "مسلسلات قصيرة تلفزيونية رباعية الأبعاد",
    "4d television news": "أخبار تلفزيونية رباعية الأبعاد",
    "4d television programmes": "برامج تلفزيونية رباعية الأبعاد",
    "4d television programs": "برامج تلفزيونية رباعية الأبعاد",
    "4d television series": "مسلسلات تلفزيونية رباعية الأبعاد",
    "4d video games": "ألعاب فيديو رباعية الأبعاد",
    "4d web series": "مسلسلات ويب رباعية الأبعاد",
    "action comedy comics": "قصص مصورة حركة كوميدية",
    "action comedy film series": "سلاسل أفلام حركة كوميدية",
    "action comedy soap opera": "مسلسلات طويلة حركة كوميدية",
    "action comedy television episodes": "حلقات تلفزيونية حركة كوميدية",
    "action comedy television films": "أفلام تلفزيونية حركة كوميدية",
    "action comedy television miniseries": "مسلسلات قصيرة تلفزيونية حركة كوميدية",
    "action comedy television news": "أخبار تلفزيونية حركة كوميدية",
    "action comedy television programmes": "برامج تلفزيونية حركة كوميدية",
    "action comedy television programs": "برامج تلفزيونية حركة كوميدية",
    "action comedy television series": "مسلسلات تلفزيونية حركة كوميدية",
    "action comedy video games": "ألعاب فيديو حركة كوميدية",
    "action comedy web series": "مسلسلات ويب حركة كوميدية",
    "action comics": "قصص مصورة حركة",
    "action film series": "سلاسل أفلام حركة",
    "action films": "أفلام حركة",
    "action soap opera": "مسلسلات طويلة حركة",
    "action television episodes": "حلقات تلفزيونية حركة",
    "action television films": "أفلام تلفزيونية حركة",
    "action television miniseries": "مسلسلات قصيرة تلفزيونية حركة",
    "action television news": "أخبار تلفزيونية حركة",
    "action television programmes": "برامج تلفزيونية حركة",
    "action television programs": "برامج تلفزيونية حركة",
    "action television series": "مسلسلات تلفزيونية حركة",
    "action thriller comics": "قصص مصورة إثارة حركة",
    "action thriller film series": "سلاسل أفلام إثارة حركة",
    "action thriller soap opera": "مسلسلات طويلة إثارة حركة",
    "action thriller television episodes": "حلقات تلفزيونية إثارة حركة",
    "action thriller television films": "أفلام تلفزيونية إثارة حركة",
    "action thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة حركة",
    "action thriller television news": "أخبار تلفزيونية إثارة حركة",
    "action thriller television programmes": "برامج تلفزيونية إثارة حركة",
    "action thriller television programs": "برامج تلفزيونية إثارة حركة",
    "action thriller television series": "مسلسلات تلفزيونية إثارة حركة",
    "action thriller video games": "ألعاب فيديو إثارة حركة",
    "action thriller web series": "مسلسلات ويب إثارة حركة",
    "action video games": "ألعاب فيديو حركة",
    "action web series": "مسلسلات ويب حركة",
    "adaptation comics": "قصص مصورة مقتبسة",
    "adaptation film series": "سلاسل أفلام مقتبسة",
    "adaptation soap opera": "مسلسلات طويلة مقتبسة",
    "adaptation television episodes": "حلقات تلفزيونية مقتبسة",
    "adaptation television films": "أفلام تلفزيونية مقتبسة",
    "adaptation television miniseries": "مسلسلات قصيرة تلفزيونية مقتبسة",
    "adaptation television news": "أخبار تلفزيونية مقتبسة",
    "adaptation television programmes": "برامج تلفزيونية مقتبسة",
    "adaptation television programs": "برامج تلفزيونية مقتبسة",
    "adaptation television series": "مسلسلات تلفزيونية مقتبسة",
    "adaptation video games": "ألعاب فيديو مقتبسة",
    "adaptation web series": "مسلسلات ويب مقتبسة",
    "adult animated comics": "قصص مصورة رسوم متحركة للكبار",
    "adult animated drama comics": "قصص مصورة رسوم متحركة دراما للكبار",
    "adult animated drama film series": "سلاسل أفلام رسوم متحركة دراما للكبار",
    "adult animated drama soap opera": "مسلسلات طويلة رسوم متحركة دراما للكبار",
    "adult animated drama television episodes": "حلقات تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated drama television films": "أفلام تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated drama television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated drama television news": "أخبار تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated drama television programmes": "برامج تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated drama television programs": "برامج تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated drama television series": "مسلسلات تلفزيونية رسوم متحركة دراما للكبار",
    "adult animated drama video games": "ألعاب فيديو رسوم متحركة دراما للكبار",
    "adult animated drama web series": "مسلسلات ويب رسوم متحركة دراما للكبار",
    "adult animated film series": "سلاسل أفلام رسوم متحركة للكبار",
    "adult animated soap opera": "مسلسلات طويلة رسوم متحركة للكبار",
    "adult animated supernatural comics": "قصص مصورة رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural film series": "سلاسل أفلام رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural soap opera": "مسلسلات طويلة رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural television episodes": "حلقات تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural television films": "أفلام تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural television news": "أخبار تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural television programmes": "برامج تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural television programs": "برامج تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural television series": "مسلسلات تلفزيونية رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural video games": "ألعاب فيديو رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated supernatural web series": "مسلسلات ويب رسوم متحركة خارقة للطبيعة للكبار",
    "adult animated television episodes": "حلقات تلفزيونية رسوم متحركة للكبار",
    "adult animated television films": "أفلام تلفزيونية رسوم متحركة للكبار",
    "adult animated television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة للكبار",
    "adult animated television news": "أخبار تلفزيونية رسوم متحركة للكبار",
    "adult animated television programmes": "برامج تلفزيونية رسوم متحركة للكبار",
    "adult animated television programs": "برامج تلفزيونية رسوم متحركة للكبار",
    "adult animated television series": "مسلسلات تلفزيونية رسوم متحركة للكبار",
    "adult animated video games": "ألعاب فيديو رسوم متحركة للكبار",
    "adult animated web series": "مسلسلات ويب رسوم متحركة للكبار",
    "adventure comics": "قصص مصورة مغامرات",
    "adventure film series": "سلاسل أفلام مغامرات",
    "adventure films": "أفلام مغامرات",
    "adventure soap opera": "مسلسلات طويلة مغامرات",
    "adventure television episodes": "حلقات تلفزيونية مغامرات",
    "adventure television films": "أفلام تلفزيونية مغامرات",
    "adventure television miniseries": "مسلسلات قصيرة تلفزيونية مغامرات",
    "adventure television news": "أخبار تلفزيونية مغامرات",
    "adventure television programmes": "برامج تلفزيونية مغامرات",
    "adventure television programs": "برامج تلفزيونية مغامرات",
    "adventure television series": "مسلسلات تلفزيونية مغامرات",
    "adventure video games": "ألعاب فيديو مغامرات",
    "adventure web series": "مسلسلات ويب مغامرات",
    "animated comics": "قصص مصورة رسوم متحركة",
    "animated film series": "سلاسل أفلام رسوم متحركة",
    "animated films": "أفلام رسوم متحركة",
    "animated science comics": "قصص مصورة علمية رسوم متحركة",
    "animated science film series": "سلاسل أفلام علمية رسوم متحركة",
    "animated science soap opera": "مسلسلات طويلة علمية رسوم متحركة",
    "animated science television episodes": "حلقات تلفزيونية علمية رسوم متحركة",
    "animated science television films": "أفلام تلفزيونية علمية رسوم متحركة",
    "animated science television miniseries": "مسلسلات قصيرة تلفزيونية علمية رسوم متحركة",
    "animated science television news": "أخبار تلفزيونية علمية رسوم متحركة",
    "animated science television programmes": "برامج تلفزيونية علمية رسوم متحركة",
    "animated science television programs": "برامج تلفزيونية علمية رسوم متحركة",
    "animated science television series": "مسلسلات تلفزيونية علمية رسوم متحركة",
    "animated science video games": "ألعاب فيديو علمية رسوم متحركة",
    "animated science web series": "مسلسلات ويب علمية رسوم متحركة",
    "animated short comics": "قصص مصورة رسوم متحركة قصيرة",
    "animated short soap opera": "مسلسلات طويلة رسوم متحركة قصيرة",
    "animated short television episodes": "حلقات تلفزيونية رسوم متحركة قصيرة",
    "animated short television films": "أفلام تلفزيونية رسوم متحركة قصيرة",
    "animated short television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة قصيرة",
    "animated short television news": "أخبار تلفزيونية رسوم متحركة قصيرة",
    "animated short television programmes": "برامج تلفزيونية رسوم متحركة قصيرة",
    "animated short television programs": "برامج تلفزيونية رسوم متحركة قصيرة",
    "animated short television series": "مسلسلات تلفزيونية رسوم متحركة قصيرة",
    "animated short video games": "ألعاب فيديو رسوم متحركة قصيرة",
    "animated short web series": "مسلسلات ويب رسوم متحركة قصيرة",
    "animated soap opera": "مسلسلات طويلة رسوم متحركة",
    "animated television episodes": "حلقات تلفزيونية رسوم متحركة",
    "animated television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة",
    "animated television news": "أخبار تلفزيونية رسوم متحركة",
    "animated television programmes": "برامج تلفزيونية رسوم متحركة",
    "animated television programs": "برامج تلفزيونية رسوم متحركة",
    "animated video games": "ألعاب فيديو رسوم متحركة",
    "animated web series": "مسلسلات ويب رسوم متحركة",
    "animation comics": "قصص مصورة رسوم متحركة",
    "animation film series": "سلاسل أفلام رسوم متحركة",
    "animation soap opera": "مسلسلات طويلة رسوم متحركة",
    "animation television episodes": "حلقات تلفزيونية رسوم متحركة",
    "animation television films": "أفلام تلفزيونية رسوم متحركة",
    "animation television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة",
    "animation television news": "أخبار تلفزيونية رسوم متحركة",
    "animation television programmes": "برامج تلفزيونية رسوم متحركة",
    "animation television programs": "برامج تلفزيونية رسوم متحركة",
    "animation television series": "مسلسلات تلفزيونية رسوم متحركة",
    "animation video games": "ألعاب فيديو رسوم متحركة",
    "animation web series": "مسلسلات ويب رسوم متحركة",
    "anime and manga characters": "شخصيات أنمي ومانغا",
    "anime comics": "قصص مصورة أنمي",
    "anime film series": "سلاسل أفلام أنمي",
    "anime films": "أفلام أنمي",
    "anime soap opera": "مسلسلات طويلة أنمي",
    "anime video games": "ألعاب فيديو أنمي",
    "anime web series": "مسلسلات ويب أنمي",
    "anthology comics": "قصص مصورة أنثولوجيا",
    "anthology film series": "سلاسل أفلام أنثولوجيا",
    "anthology films": "أفلام أنثولوجيا",
    "anthology soap opera": "مسلسلات طويلة أنثولوجيا",
    "anthology television episodes": "حلقات تلفزيونية أنثولوجيا",
    "anthology television films": "أفلام تلفزيونية أنثولوجيا",
    "anthology television miniseries": "مسلسلات قصيرة تلفزيونية أنثولوجيا",
    "anthology television news": "أخبار تلفزيونية أنثولوجيا",
    "anthology television programmes": "برامج تلفزيونية أنثولوجيا",
    "anthology television programs": "برامج تلفزيونية أنثولوجيا",
    "anthology television series": "مسلسلات تلفزيونية أنثولوجيا",
    "anthology video games": "ألعاب فيديو أنثولوجيا",
    "anthology web series": "مسلسلات ويب أنثولوجيا",
    "apocalyptic comics": "قصص مصورة نهاية العالم",
    "apocalyptic film series": "سلاسل أفلام نهاية العالم",
    "apocalyptic soap opera": "مسلسلات طويلة نهاية العالم",
    "apocalyptic television episodes": "حلقات تلفزيونية نهاية العالم",
    "apocalyptic television films": "أفلام تلفزيونية نهاية العالم",
    "apocalyptic television miniseries": "مسلسلات قصيرة تلفزيونية نهاية العالم",
    "apocalyptic television news": "أخبار تلفزيونية نهاية العالم",
    "apocalyptic television programmes": "برامج تلفزيونية نهاية العالم",
    "apocalyptic television programs": "برامج تلفزيونية نهاية العالم",
    "apocalyptic television series": "مسلسلات تلفزيونية نهاية العالم",
    "apocalyptic video games": "ألعاب فيديو نهاية العالم",
    "apocalyptic web series": "مسلسلات ويب نهاية العالم",
    "astronomical comics": "قصص مصورة فلكية",
    "astronomical film series": "سلاسل أفلام فلكية",
    "astronomical soap opera": "مسلسلات طويلة فلكية",
    "astronomical television episodes": "حلقات تلفزيونية فلكية",
    "astronomical television films": "أفلام تلفزيونية فلكية",
    "astronomical television miniseries": "مسلسلات قصيرة تلفزيونية فلكية",
    "astronomical television news": "أخبار تلفزيونية فلكية",
    "astronomical television programmes": "برامج تلفزيونية فلكية",
    "astronomical television programs": "برامج تلفزيونية فلكية",
    "astronomical television series": "مسلسلات تلفزيونية فلكية",
    "astronomical video games": "ألعاب فيديو فلكية",
    "astronomical web series": "مسلسلات ويب فلكية",
    "aviation comics": "قصص مصورة طيران",
    "aviation film series": "سلاسل أفلام طيران",
    "aviation soap opera": "مسلسلات طويلة طيران",
    "aviation television episodes": "حلقات تلفزيونية طيران",
    "aviation television films": "أفلام تلفزيونية طيران",
    "aviation television miniseries": "مسلسلات قصيرة تلفزيونية طيران",
    "aviation television news": "أخبار تلفزيونية طيران",
    "aviation television programmes": "برامج تلفزيونية طيران",
    "aviation television programs": "برامج تلفزيونية طيران",
    "aviation television series": "مسلسلات تلفزيونية طيران",
    "aviation video games": "ألعاب فيديو طيران",
    "aviation web series": "مسلسلات ويب طيران",
    "b movie comics": "قصص مصورة درجة ثانية",
    "b movie film series": "سلاسل أفلام درجة ثانية",
    "b movie soap opera": "مسلسلات طويلة درجة ثانية",
    "b movie television episodes": "حلقات تلفزيونية درجة ثانية",
    "b movie television films": "أفلام تلفزيونية درجة ثانية",
    "b movie television miniseries": "مسلسلات قصيرة تلفزيونية درجة ثانية",
    "b movie television news": "أخبار تلفزيونية درجة ثانية",
    "b movie television programmes": "برامج تلفزيونية درجة ثانية",
    "b movie television programs": "برامج تلفزيونية درجة ثانية",
    "b movie television series": "مسلسلات تلفزيونية درجة ثانية",
    "b movie video games": "ألعاب فيديو درجة ثانية",
    "b movie web series": "مسلسلات ويب درجة ثانية",
    "biographical comics": "قصص مصورة سير ذاتية",
    "biographical film series": "سلاسل أفلام سير ذاتية",
    "biographical soap opera": "مسلسلات طويلة سير ذاتية",
    "biographical television episodes": "حلقات تلفزيونية سير ذاتية",
    "biographical television films": "أفلام تلفزيونية سير ذاتية",
    "biographical television miniseries": "مسلسلات قصيرة تلفزيونية سير ذاتية",
    "biographical television news": "أخبار تلفزيونية سير ذاتية",
    "biographical television programmes": "برامج تلفزيونية سير ذاتية",
    "biographical television programs": "برامج تلفزيونية سير ذاتية",
    "biographical television series": "مسلسلات تلفزيونية سير ذاتية",
    "biographical video games": "ألعاب فيديو سير ذاتية",
    "biographical web series": "مسلسلات ويب سير ذاتية",
    "black and white comics": "قصص مصورة أبيض وأسود",
    "black and white film series": "سلاسل أفلام أبيض وأسود",
    "black and white soap opera": "مسلسلات طويلة أبيض وأسود",
    "black and white television episodes": "حلقات تلفزيونية أبيض وأسود",
    "black and white television films": "أفلام تلفزيونية أبيض وأسود",
    "black and white television miniseries": "مسلسلات قصيرة تلفزيونية أبيض وأسود",
    "black and white television news": "أخبار تلفزيونية أبيض وأسود",
    "black and white television programmes": "برامج تلفزيونية أبيض وأسود",
    "black and white television programs": "برامج تلفزيونية أبيض وأسود",
    "black and white television series": "مسلسلات تلفزيونية أبيض وأسود",
    "black and white video games": "ألعاب فيديو أبيض وأسود",
    "black and white web series": "مسلسلات ويب أبيض وأسود",
    "black comedy comics": "قصص مصورة كوميدية سوداء",
    "black comedy film series": "سلاسل أفلام كوميدية سوداء",
    "black comedy films": "أفلام كوميدية سوداء",
    "black comedy soap opera": "مسلسلات طويلة كوميدية سوداء",
    "black comedy television episodes": "حلقات تلفزيونية كوميدية سوداء",
    "black comedy television films": "أفلام تلفزيونية كوميدية سوداء",
    "black comedy television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية سوداء",
    "black comedy television news": "أخبار تلفزيونية كوميدية سوداء",
    "black comedy television programmes": "برامج تلفزيونية كوميدية سوداء",
    "black comedy television programs": "برامج تلفزيونية كوميدية سوداء",
    "black comedy television series": "مسلسلات تلفزيونية كوميدية سوداء",
    "black comedy video games": "ألعاب فيديو كوميدية سوداء",
    "black comedy web series": "مسلسلات ويب كوميدية سوداء",
    "black comics": "قصص مصورة سوداء",
    "black film series": "سلاسل أفلام سوداء",
    "black soap opera": "مسلسلات طويلة سوداء",
    "black television episodes": "حلقات تلفزيونية سوداء",
    "black television films": "أفلام تلفزيونية سوداء",
    "black television miniseries": "مسلسلات قصيرة تلفزيونية سوداء",
    "black television news": "أخبار تلفزيونية سوداء",
    "black television programmes": "برامج تلفزيونية سوداء",
    "black television programs": "برامج تلفزيونية سوداء",
    "black television series": "مسلسلات تلفزيونية سوداء",
    "black video games": "ألعاب فيديو سوداء",
    "black web series": "مسلسلات ويب سوداء",
    "bollywood comics": "قصص مصورة بوليوود",
    "bollywood film series": "سلاسل أفلام بوليوود",
    "bollywood soap opera": "مسلسلات طويلة بوليوود",
    "bollywood television episodes": "حلقات تلفزيونية بوليوود",
    "bollywood television films": "أفلام تلفزيونية بوليوود",
    "bollywood television miniseries": "مسلسلات قصيرة تلفزيونية بوليوود",
    "bollywood television news": "أخبار تلفزيونية بوليوود",
    "bollywood television programmes": "برامج تلفزيونية بوليوود",
    "bollywood television programs": "برامج تلفزيونية بوليوود",
    "bollywood television series": "مسلسلات تلفزيونية بوليوود",
    "bollywood video games": "ألعاب فيديو بوليوود",
    "bollywood web series": "مسلسلات ويب بوليوود",
    "buddy comics": "قصص مصورة رفقاء",
    "buddy film series": "سلاسل أفلام رفقاء",
    "buddy films": "أفلام رفقاء",
    "buddy soap opera": "مسلسلات طويلة رفقاء",
    "buddy television episodes": "حلقات تلفزيونية رفقاء",
    "buddy television films": "أفلام تلفزيونية رفقاء",
    "buddy television miniseries": "مسلسلات قصيرة تلفزيونية رفقاء",
    "buddy television news": "أخبار تلفزيونية رفقاء",
    "buddy television programmes": "برامج تلفزيونية رفقاء",
    "buddy television programs": "برامج تلفزيونية رفقاء",
    "buddy television series": "مسلسلات تلفزيونية رفقاء",
    "buddy video games": "ألعاب فيديو رفقاء",
    "buddy web series": "مسلسلات ويب رفقاء",
    "cancelled comics": "قصص مصورة ملغية",
    "cancelled film series": "سلاسل أفلام ملغية",
    "cancelled soap opera": "مسلسلات طويلة ملغية",
    "cancelled television episodes": "حلقات تلفزيونية ملغية",
    "cancelled television films": "أفلام تلفزيونية ملغية",
    "cancelled television miniseries": "مسلسلات قصيرة تلفزيونية ملغية",
    "cancelled television news": "أخبار تلفزيونية ملغية",
    "cancelled television programmes": "برامج تلفزيونية ملغية",
    "cancelled television programs": "برامج تلفزيونية ملغية",
    "cancelled television series": "مسلسلات تلفزيونية ملغية",
    "cancelled video games": "ألعاب فيديو ملغية",
    "cancelled web series": "مسلسلات ويب ملغية",
    "cannibal comics": "قصص مصورة آكلو لحم البشر",
    "cannibal film series": "سلاسل أفلام آكلو لحم البشر",
    "cannibal soap opera": "مسلسلات طويلة آكلو لحم البشر",
    "cannibal television episodes": "حلقات تلفزيونية آكلو لحم البشر",
    "cannibal television films": "أفلام تلفزيونية آكلو لحم البشر",
    "cannibal television miniseries": "مسلسلات قصيرة تلفزيونية آكلو لحم البشر",
    "cannibal television news": "أخبار تلفزيونية آكلو لحم البشر",
    "cannibal television programmes": "برامج تلفزيونية آكلو لحم البشر",
    "cannibal television programs": "برامج تلفزيونية آكلو لحم البشر",
    "cannibal television series": "مسلسلات تلفزيونية آكلو لحم البشر",
    "cannibal video games": "ألعاب فيديو آكلو لحم البشر",
    "cannibal web series": "مسلسلات ويب آكلو لحم البشر",
    "chase comics": "قصص مصورة مطاردة",
    "chase film series": "سلاسل أفلام مطاردة",
    "chase soap opera": "مسلسلات طويلة مطاردة",
    "chase television episodes": "حلقات تلفزيونية مطاردة",
    "chase television films": "أفلام تلفزيونية مطاردة",
    "chase television miniseries": "مسلسلات قصيرة تلفزيونية مطاردة",
    "chase television news": "أخبار تلفزيونية مطاردة",
    "chase television programmes": "برامج تلفزيونية مطاردة",
    "chase television programs": "برامج تلفزيونية مطاردة",
    "chase television series": "مسلسلات تلفزيونية مطاردة",
    "chase video games": "ألعاب فيديو مطاردة",
    "chase web series": "مسلسلات ويب مطاردة",
    "children's animated comics": "قصص مصورة رسوم متحركة أطفال",
    "children's animated film series": "سلاسل أفلام رسوم متحركة أطفال",
    "children's animated soap opera": "مسلسلات طويلة رسوم متحركة أطفال",
    "children's animated television episodes": "حلقات تلفزيونية رسوم متحركة أطفال",
    "children's animated television films": "أفلام تلفزيونية رسوم متحركة أطفال",
    "children's animated television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة أطفال",
    "children's animated television news": "أخبار تلفزيونية رسوم متحركة أطفال",
    "children's animated television programmes": "برامج تلفزيونية رسوم متحركة أطفال",
    "children's animated television programs": "برامج تلفزيونية رسوم متحركة أطفال",
    "children's animated television series": "مسلسلات تلفزيونية رسوم متحركة أطفال",
    "children's animated video games": "ألعاب فيديو رسوم متحركة أطفال",
    "children's animated web series": "مسلسلات ويب رسوم متحركة أطفال",
    "children's comedy comics": "قصص مصورة أطفال كوميدية",
    "children's comedy film series": "سلاسل أفلام أطفال كوميدية",
    "children's comedy soap opera": "مسلسلات طويلة أطفال كوميدية",
    "children's comedy television episodes": "حلقات تلفزيونية أطفال كوميدية",
    "children's comedy television films": "أفلام تلفزيونية أطفال كوميدية",
    "children's comedy television miniseries": "مسلسلات قصيرة تلفزيونية أطفال كوميدية",
    "children's comedy television news": "أخبار تلفزيونية أطفال كوميدية",
    "children's comedy television programmes": "برامج تلفزيونية أطفال كوميدية",
    "children's comedy television programs": "برامج تلفزيونية أطفال كوميدية",
    "children's comedy television series": "مسلسلات تلفزيونية أطفال كوميدية",
    "children's comedy video games": "ألعاب فيديو أطفال كوميدية",
    "children's comedy web series": "مسلسلات ويب أطفال كوميدية",
    "children's comics": "قصص مصورة أطفال",
    "children's film series": "سلاسل أفلام أطفال",
    "children's soap opera": "مسلسلات طويلة أطفال",
    "children's television episodes": "حلقات تلفزيونية أطفال",
    "children's television films": "أفلام تلفزيونية أطفال",
    "children's television miniseries": "مسلسلات قصيرة تلفزيونية أطفال",
    "children's television news": "أخبار تلفزيونية أطفال",
    "children's television programmes": "برامج تلفزيونية أطفال",
    "children's television programs": "برامج تلفزيونية أطفال",
    "children's television series": "مسلسلات تلفزيونية أطفال",
    "children's video games": "ألعاب فيديو أطفال",
    "children's web series": "مسلسلات ويب أطفال",
    "christmas comics": "قصص مصورة عيد الميلاد",
    "christmas film series": "سلاسل أفلام عيد الميلاد",
    "christmas soap opera": "مسلسلات طويلة عيد الميلاد",
    "christmas television episodes": "حلقات تلفزيونية عيد الميلاد",
    "christmas television films": "أفلام تلفزيونية عيد الميلاد",
    "christmas television miniseries": "مسلسلات قصيرة تلفزيونية عيد الميلاد",
    "christmas television news": "أخبار تلفزيونية عيد الميلاد",
    "christmas television programmes": "برامج تلفزيونية عيد الميلاد",
    "christmas television programs": "برامج تلفزيونية عيد الميلاد",
    "christmas television series": "مسلسلات تلفزيونية عيد الميلاد",
    "christmas video games": "ألعاب فيديو عيد الميلاد",
    "christmas web series": "مسلسلات ويب عيد الميلاد",
    "colonial cinema comics": "قصص مصورة استعمار",
    "colonial cinema film series": "سلاسل أفلام استعمار",
    "colonial cinema soap opera": "مسلسلات طويلة استعمار",
    "colonial cinema television episodes": "حلقات تلفزيونية استعمار",
    "colonial cinema television films": "أفلام تلفزيونية استعمار",
    "colonial cinema television miniseries": "مسلسلات قصيرة تلفزيونية استعمار",
    "colonial cinema television news": "أخبار تلفزيونية استعمار",
    "colonial cinema television programmes": "برامج تلفزيونية استعمار",
    "colonial cinema television programs": "برامج تلفزيونية استعمار",
    "colonial cinema television series": "مسلسلات تلفزيونية استعمار",
    "colonial cinema video games": "ألعاب فيديو استعمار",
    "colonial cinema web series": "مسلسلات ويب استعمار",
    "comedy comics": "قصص مصورة كوميدية",
    "comedy drama comics": "قصص مصورة كوميدية درامية",
    "comedy drama film series": "سلاسل أفلام كوميدية درامية",
    "comedy drama soap opera": "مسلسلات طويلة كوميدية درامية",
    "comedy drama television episodes": "حلقات تلفزيونية كوميدية درامية",
    "comedy drama television films": "أفلام تلفزيونية كوميدية درامية",
    "comedy drama television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية درامية",
    "comedy drama television news": "أخبار تلفزيونية كوميدية درامية",
    "comedy drama television programmes": "برامج تلفزيونية كوميدية درامية",
    "comedy drama television programs": "برامج تلفزيونية كوميدية درامية",
    "comedy drama television series": "مسلسلات تلفزيونية كوميدية درامية",
    "comedy drama video games": "ألعاب فيديو كوميدية درامية",
    "comedy drama web series": "مسلسلات ويب كوميدية درامية",
    "comedy fiction comics": "قصص مصورة كوميدية خيالية",
    "comedy fiction film series": "سلاسل أفلام كوميدية خيالية",
    "comedy fiction soap opera": "مسلسلات طويلة كوميدية خيالية",
    "comedy fiction television episodes": "حلقات تلفزيونية كوميدية خيالية",
    "comedy fiction television films": "أفلام تلفزيونية كوميدية خيالية",
    "comedy fiction television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية خيالية",
    "comedy fiction television news": "أخبار تلفزيونية كوميدية خيالية",
    "comedy fiction television programmes": "برامج تلفزيونية كوميدية خيالية",
    "comedy fiction television programs": "برامج تلفزيونية كوميدية خيالية",
    "comedy fiction television series": "مسلسلات تلفزيونية كوميدية خيالية",
    "comedy fiction video games": "ألعاب فيديو كوميدية خيالية",
    "comedy fiction web series": "مسلسلات ويب كوميدية خيالية",
    "comedy film series": "سلاسل أفلام كوميدية",
    "comedy films": "أفلام كوميدية",
    "comedy horror comics": "قصص مصورة كوميدية رعب",
    "comedy horror film series": "سلاسل أفلام كوميدية رعب",
    "comedy horror soap opera": "مسلسلات طويلة كوميدية رعب",
    "comedy horror television episodes": "حلقات تلفزيونية كوميدية رعب",
    "comedy horror television films": "أفلام تلفزيونية كوميدية رعب",
    "comedy horror television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية رعب",
    "comedy horror television news": "أخبار تلفزيونية كوميدية رعب",
    "comedy horror television programmes": "برامج تلفزيونية كوميدية رعب",
    "comedy horror television programs": "برامج تلفزيونية كوميدية رعب",
    "comedy horror television series": "مسلسلات تلفزيونية كوميدية رعب",
    "comedy horror video games": "ألعاب فيديو كوميدية رعب",
    "comedy horror web series": "مسلسلات ويب كوميدية رعب",
    "comedy soap opera": "مسلسلات طويلة كوميدية",
    "comedy television episodes": "حلقات تلفزيونية كوميدية",
    "comedy television films": "أفلام تلفزيونية كوميدية",
    "comedy television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية",
    "comedy television news": "أخبار تلفزيونية كوميدية",
    "comedy television programmes": "برامج تلفزيونية كوميدية",
    "comedy television programs": "برامج تلفزيونية كوميدية",
    "comedy television series": "مسلسلات تلفزيونية كوميدية",
    "comedy thriller comics": "قصص مصورة كوميدية إثارة",
    "comedy thriller film series": "سلاسل أفلام كوميدية إثارة",
    "comedy thriller soap opera": "مسلسلات طويلة كوميدية إثارة",
    "comedy thriller television episodes": "حلقات تلفزيونية كوميدية إثارة",
    "comedy thriller television films": "أفلام تلفزيونية كوميدية إثارة",
    "comedy thriller television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية إثارة",
    "comedy thriller television news": "أخبار تلفزيونية كوميدية إثارة",
    "comedy thriller television programmes": "برامج تلفزيونية كوميدية إثارة",
    "comedy thriller television programs": "برامج تلفزيونية كوميدية إثارة",
    "comedy thriller television series": "مسلسلات تلفزيونية كوميدية إثارة",
    "comedy thriller video games": "ألعاب فيديو كوميدية إثارة",
    "comedy thriller web series": "مسلسلات ويب كوميدية إثارة",
    "comedy video games": "ألعاب فيديو كوميدية",
    "comedy web series": "مسلسلات ويب كوميدية",
    "comics characters": "شخصيات قصص مصورة",
    "comics images": "صور قصص مصورة",
    "computer animated comics": "قصص مصورة حركة حاسوبية",
    "computer animated film series": "سلاسل أفلام حركة حاسوبية",
    "computer animated soap opera": "مسلسلات طويلة حركة حاسوبية",
    "computer animated television episodes": "حلقات تلفزيونية حركة حاسوبية",
    "computer animated television films": "أفلام تلفزيونية حركة حاسوبية",
    "computer animated television miniseries": "مسلسلات قصيرة تلفزيونية حركة حاسوبية",
    "computer animated television news": "أخبار تلفزيونية حركة حاسوبية",
    "computer animated television programmes": "برامج تلفزيونية حركة حاسوبية",
    "computer animated television programs": "برامج تلفزيونية حركة حاسوبية",
    "computer animated television series": "مسلسلات تلفزيونية حركة حاسوبية",
    "computer animated video games": "ألعاب فيديو حركة حاسوبية",
    "computer animated web series": "مسلسلات ويب حركة حاسوبية",
    "crime comedy comics": "قصص مصورة جنائية كوميدية",
    "crime comedy film series": "سلاسل أفلام جنائية كوميدية",
    "crime comedy soap opera": "مسلسلات طويلة جنائية كوميدية",
    "crime comedy television episodes": "حلقات تلفزيونية جنائية كوميدية",
    "crime comedy television films": "أفلام تلفزيونية جنائية كوميدية",
    "crime comedy television miniseries": "مسلسلات قصيرة تلفزيونية جنائية كوميدية",
    "crime comedy television news": "أخبار تلفزيونية جنائية كوميدية",
    "crime comedy television programmes": "برامج تلفزيونية جنائية كوميدية",
    "crime comedy television programs": "برامج تلفزيونية جنائية كوميدية",
    "crime comedy television series": "مسلسلات تلفزيونية جنائية كوميدية",
    "crime comedy video games": "ألعاب فيديو جنائية كوميدية",
    "crime comedy web series": "مسلسلات ويب جنائية كوميدية",
    "crime comics": "قصص مصورة جريمة",
    "crime film series": "سلاسل أفلام جريمة",
    "crime films": "أفلام جريمة",
    "crime soap opera": "مسلسلات طويلة جريمة",
    "crime television episodes": "حلقات تلفزيونية جريمة",
    "crime television films": "أفلام تلفزيونية جريمة",
    "crime television miniseries": "مسلسلات قصيرة تلفزيونية جريمة",
    "crime television news": "أخبار تلفزيونية جريمة",
    "crime television programmes": "برامج تلفزيونية جريمة",
    "crime television programs": "برامج تلفزيونية جريمة",
    "crime television series": "مسلسلات تلفزيونية جريمة",
    "crime thriller comics": "قصص مصورة إثارة وجريمة",
    "crime thriller film series": "سلاسل أفلام إثارة وجريمة",
    "crime thriller soap opera": "مسلسلات طويلة إثارة وجريمة",
    "crime thriller television episodes": "حلقات تلفزيونية إثارة وجريمة",
    "crime thriller television films": "أفلام تلفزيونية إثارة وجريمة",
    "crime thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة وجريمة",
    "crime thriller television news": "أخبار تلفزيونية إثارة وجريمة",
    "crime thriller television programmes": "برامج تلفزيونية إثارة وجريمة",
    "crime thriller television programs": "برامج تلفزيونية إثارة وجريمة",
    "crime thriller television series": "مسلسلات تلفزيونية إثارة وجريمة",
    "crime thriller video games": "ألعاب فيديو إثارة وجريمة",
    "crime thriller web series": "مسلسلات ويب إثارة وجريمة",
    "crime video games": "ألعاب فيديو جريمة",
    "crime web series": "مسلسلات ويب جريمة",
    "criminal comedy comics": "قصص مصورة كوميديا الجريمة",
    "criminal comedy film series": "سلاسل أفلام كوميديا الجريمة",
    "criminal comedy soap opera": "مسلسلات طويلة كوميديا الجريمة",
    "criminal comedy television episodes": "حلقات تلفزيونية كوميديا الجريمة",
    "criminal comedy television films": "أفلام تلفزيونية كوميديا الجريمة",
    "criminal comedy television miniseries": "مسلسلات قصيرة تلفزيونية كوميديا الجريمة",
    "criminal comedy television news": "أخبار تلفزيونية كوميديا الجريمة",
    "criminal comedy television programmes": "برامج تلفزيونية كوميديا الجريمة",
    "criminal comedy television programs": "برامج تلفزيونية كوميديا الجريمة",
    "criminal comedy television series": "مسلسلات تلفزيونية كوميديا الجريمة",
    "criminal comedy video games": "ألعاب فيديو كوميديا الجريمة",
    "criminal comedy web series": "مسلسلات ويب كوميديا الجريمة",
    "criminal comics": "قصص مصورة جنائية",
    "criminal film series": "سلاسل أفلام جنائية",
    "criminal soap opera": "مسلسلات طويلة جنائية",
    "criminal television episodes": "حلقات تلفزيونية جنائية",
    "criminal television films": "أفلام تلفزيونية جنائية",
    "criminal television miniseries": "مسلسلات قصيرة تلفزيونية جنائية",
    "criminal television news": "أخبار تلفزيونية جنائية",
    "criminal television programmes": "برامج تلفزيونية جنائية",
    "criminal television programs": "برامج تلفزيونية جنائية",
    "criminal television series": "مسلسلات تلفزيونية جنائية",
    "criminal video games": "ألعاب فيديو جنائية",
    "criminal web series": "مسلسلات ويب جنائية",
    "cyberpunk comics": "قصص مصورة سايبربانك",
    "cyberpunk film series": "سلاسل أفلام سايبربانك",
    "cyberpunk soap opera": "مسلسلات طويلة سايبربانك",
    "cyberpunk television episodes": "حلقات تلفزيونية سايبربانك",
    "cyberpunk television films": "أفلام تلفزيونية سايبربانك",
    "cyberpunk television miniseries": "مسلسلات قصيرة تلفزيونية سايبربانك",
    "cyberpunk television news": "أخبار تلفزيونية سايبربانك",
    "cyberpunk television programmes": "برامج تلفزيونية سايبربانك",
    "cyberpunk television programs": "برامج تلفزيونية سايبربانك",
    "cyberpunk television series": "مسلسلات تلفزيونية سايبربانك",
    "cyberpunk video games": "ألعاب فيديو سايبربانك",
    "cyberpunk web series": "مسلسلات ويب سايبربانك",
    "dance comics": "قصص مصورة رقص",
    "dance film series": "سلاسل أفلام رقص",
    "dance soap opera": "مسلسلات طويلة رقص",
    "dance television episodes": "حلقات تلفزيونية رقص",
    "dance television films": "أفلام تلفزيونية رقص",
    "dance television miniseries": "مسلسلات قصيرة تلفزيونية رقص",
    "dance television news": "أخبار تلفزيونية رقص",
    "dance television programmes": "برامج تلفزيونية رقص",
    "dance television programs": "برامج تلفزيونية رقص",
    "dance television series": "مسلسلات تلفزيونية رقص",
    "dance video games": "ألعاب فيديو رقص",
    "dance web series": "مسلسلات ويب رقص",
    "dark fantasy comics": "قصص مصورة فانتازيا مظلمة",
    "dark fantasy film series": "سلاسل أفلام فانتازيا مظلمة",
    "dark fantasy films": "أفلام فانتازيا مظلمة",
    "dark fantasy soap opera": "مسلسلات طويلة فانتازيا مظلمة",
    "dark fantasy television episodes": "حلقات تلفزيونية فانتازيا مظلمة",
    "dark fantasy television films": "أفلام تلفزيونية فانتازيا مظلمة",
    "dark fantasy television miniseries": "مسلسلات قصيرة تلفزيونية فانتازيا مظلمة",
    "dark fantasy television news": "أخبار تلفزيونية فانتازيا مظلمة",
    "dark fantasy television programmes": "برامج تلفزيونية فانتازيا مظلمة",
    "dark fantasy television programs": "برامج تلفزيونية فانتازيا مظلمة",
    "dark fantasy television series": "مسلسلات تلفزيونية فانتازيا مظلمة",
    "dark fantasy video games": "ألعاب فيديو فانتازيا مظلمة",
    "dark fantasy web series": "مسلسلات ويب فانتازيا مظلمة",
    "detective comics": "قصص مصورة مباحث",
    "detective fiction comics": "قصص مصورة خيالية بوليسية",
    "detective fiction film series": "سلاسل أفلام خيالية بوليسية",
    "detective fiction soap opera": "مسلسلات طويلة خيالية بوليسية",
    "detective fiction television episodes": "حلقات تلفزيونية خيالية بوليسية",
    "detective fiction television films": "أفلام تلفزيونية خيالية بوليسية",
    "detective fiction television miniseries": "مسلسلات قصيرة تلفزيونية خيالية بوليسية",
    "detective fiction television news": "أخبار تلفزيونية خيالية بوليسية",
    "detective fiction television programmes": "برامج تلفزيونية خيالية بوليسية",
    "detective fiction television programs": "برامج تلفزيونية خيالية بوليسية",
    "detective fiction television series": "مسلسلات تلفزيونية خيالية بوليسية",
    "detective fiction video games": "ألعاب فيديو خيالية بوليسية",
    "detective fiction web series": "مسلسلات ويب خيالية بوليسية",
    "detective film series": "سلاسل أفلام مباحث",
    "detective soap opera": "مسلسلات طويلة مباحث",
    "detective television episodes": "حلقات تلفزيونية مباحث",
    "detective television films": "أفلام تلفزيونية مباحث",
    "detective television miniseries": "مسلسلات قصيرة تلفزيونية مباحث",
    "detective television news": "أخبار تلفزيونية مباحث",
    "detective television programmes": "برامج تلفزيونية مباحث",
    "detective television programs": "برامج تلفزيونية مباحث",
    "detective television series": "مسلسلات تلفزيونية مباحث",
    "detective video games": "ألعاب فيديو مباحث",
    "detective web series": "مسلسلات ويب مباحث",
    "disaster comics": "قصص مصورة كوارثية",
    "disaster film series": "سلاسل أفلام كوارثية",
    "disaster soap opera": "مسلسلات طويلة كوارثية",
    "disaster television episodes": "حلقات تلفزيونية كوارثية",
    "disaster television films": "أفلام تلفزيونية كوارثية",
    "disaster television miniseries": "مسلسلات قصيرة تلفزيونية كوارثية",
    "disaster television news": "أخبار تلفزيونية كوارثية",
    "disaster television programmes": "برامج تلفزيونية كوارثية",
    "disaster television programs": "برامج تلفزيونية كوارثية",
    "disaster television series": "مسلسلات تلفزيونية كوارثية",
    "disaster video games": "ألعاب فيديو كوارثية",
    "disaster web series": "مسلسلات ويب كوارثية",
    "disney animated comics": "قصص مصورة رسوم متحركة ديزني",
    "disney animated film series": "سلاسل أفلام رسوم متحركة ديزني",
    "disney animated soap opera": "مسلسلات طويلة رسوم متحركة ديزني",
    "disney animated television episodes": "حلقات تلفزيونية رسوم متحركة ديزني",
    "disney animated television films": "أفلام تلفزيونية رسوم متحركة ديزني",
    "disney animated television miniseries": "مسلسلات قصيرة تلفزيونية رسوم متحركة ديزني",
    "disney animated television news": "أخبار تلفزيونية رسوم متحركة ديزني",
    "disney animated television programmes": "برامج تلفزيونية رسوم متحركة ديزني",
    "disney animated television programs": "برامج تلفزيونية رسوم متحركة ديزني",
    "disney animated television series": "مسلسلات تلفزيونية رسوم متحركة ديزني",
    "disney animated video games": "ألعاب فيديو رسوم متحركة ديزني",
    "disney animated web series": "مسلسلات ويب رسوم متحركة ديزني",
    "docudrama comics": "قصص مصورة درامية وثائقية",
    "docudrama film series": "سلاسل أفلام درامية وثائقية",
    "docudrama soap opera": "مسلسلات طويلة درامية وثائقية",
    "docudrama television episodes": "حلقات تلفزيونية درامية وثائقية",
    "docudrama television films": "أفلام تلفزيونية درامية وثائقية",
    "docudrama television miniseries": "مسلسلات قصيرة تلفزيونية درامية وثائقية",
    "docudrama television news": "أخبار تلفزيونية درامية وثائقية",
    "docudrama television programmes": "برامج تلفزيونية درامية وثائقية",
    "docudrama television programs": "برامج تلفزيونية درامية وثائقية",
    "docudrama television series": "مسلسلات تلفزيونية درامية وثائقية",
    "docudrama video games": "ألعاب فيديو درامية وثائقية",
    "docudrama web series": "مسلسلات ويب درامية وثائقية",
    "documentary comics": "قصص مصورة وثائقية",
    "documentary film series": "سلاسل أفلام وثائقية",
    "documentary films": "أفلام وثائقية",
    "documentary soap opera": "مسلسلات طويلة وثائقية",
    "documentary television episodes": "حلقات تلفزيونية وثائقية",
    "documentary television films": "أفلام تلفزيونية وثائقية",
    "documentary television miniseries": "مسلسلات قصيرة تلفزيونية وثائقية",
    "documentary television news": "أخبار تلفزيونية وثائقية",
    "documentary television programmes": "برامج تلفزيونية وثائقية",
    "documentary television programs": "برامج تلفزيونية وثائقية",
    "documentary television series": "مسلسلات تلفزيونية وثائقية",
    "documentary video games": "ألعاب فيديو وثائقية",
    "documentary web series": "مسلسلات ويب وثائقية",
    "drama comics": "قصص مصورة درامية",
    "drama film series": "سلاسل أفلام درامية",
    "drama soap opera": "مسلسلات طويلة درامية",
    "drama television episodes": "حلقات تلفزيونية درامية",
    "drama television films": "أفلام تلفزيونية درامية",
    "drama television miniseries": "مسلسلات قصيرة تلفزيونية درامية",
    "drama television news": "أخبار تلفزيونية درامية",
    "drama television programmes": "برامج تلفزيونية درامية",
    "drama television programs": "برامج تلفزيونية درامية",
    "drama television series": "مسلسلات تلفزيونية درامية",
    "drama video games": "ألعاب فيديو درامية",
    "drama web series": "مسلسلات ويب درامية",
    "educational comics": "قصص مصورة تعليمية",
    "educational film series": "سلاسل أفلام تعليمية",
    "educational soap opera": "مسلسلات طويلة تعليمية",
    "educational television episodes": "حلقات تلفزيونية تعليمية",
    "educational television films": "أفلام تلفزيونية تعليمية",
    "educational television miniseries": "مسلسلات قصيرة تلفزيونية تعليمية",
    "educational television news": "أخبار تلفزيونية تعليمية",
    "educational television programmes": "برامج تلفزيونية تعليمية",
    "educational television programs": "برامج تلفزيونية تعليمية",
    "educational television series": "مسلسلات تلفزيونية تعليمية",
    "educational video games": "ألعاب فيديو تعليمية",
    "educational web series": "مسلسلات ويب تعليمية",
    "environment comics": "قصص مصورة بيئية",
    "environment film series": "سلاسل أفلام بيئية",
    "environment soap opera": "مسلسلات طويلة بيئية",
    "environment television episodes": "حلقات تلفزيونية بيئية",
    "environment television films": "أفلام تلفزيونية بيئية",
    "environment television miniseries": "مسلسلات قصيرة تلفزيونية بيئية",
    "environment television news": "أخبار تلفزيونية بيئية",
    "environment television programmes": "برامج تلفزيونية بيئية",
    "environment television programs": "برامج تلفزيونية بيئية",
    "environment television series": "مسلسلات تلفزيونية بيئية",
    "environment video games": "ألعاب فيديو بيئية",
    "environment web series": "مسلسلات ويب بيئية",
    "epic comics": "قصص مصورة ملحمية",
    "epic film series": "سلاسل أفلام ملحمية",
    "epic films": "أفلام ملحمية",
    "epic soap opera": "مسلسلات طويلة ملحمية",
    "epic television episodes": "حلقات تلفزيونية ملحمية",
    "epic television films": "أفلام تلفزيونية ملحمية",
    "epic television miniseries": "مسلسلات قصيرة تلفزيونية ملحمية",
    "epic television news": "أخبار تلفزيونية ملحمية",
    "epic television programmes": "برامج تلفزيونية ملحمية",
    "epic television programs": "برامج تلفزيونية ملحمية",
    "epic television series": "مسلسلات تلفزيونية ملحمية",
    "epic video games": "ألعاب فيديو ملحمية",
    "epic web series": "مسلسلات ويب ملحمية",
    "erotic comics": "قصص مصورة إغرائية",
    "erotic film series": "سلاسل أفلام إغرائية",
    "erotic soap opera": "مسلسلات طويلة إغرائية",
    "erotic television episodes": "حلقات تلفزيونية إغرائية",
    "erotic television films": "أفلام تلفزيونية إغرائية",
    "erotic television miniseries": "مسلسلات قصيرة تلفزيونية إغرائية",
    "erotic television news": "أخبار تلفزيونية إغرائية",
    "erotic television programmes": "برامج تلفزيونية إغرائية",
    "erotic television programs": "برامج تلفزيونية إغرائية",
    "erotic television series": "مسلسلات تلفزيونية إغرائية",
    "erotic thriller comics": "قصص مصورة إثارة جنسية",
    "erotic thriller film series": "سلاسل أفلام إثارة جنسية",
    "erotic thriller soap opera": "مسلسلات طويلة إثارة جنسية",
    "erotic thriller television episodes": "حلقات تلفزيونية إثارة جنسية",
    "erotic thriller television films": "أفلام تلفزيونية إثارة جنسية",
    "erotic thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة جنسية",
    "erotic thriller television news": "أخبار تلفزيونية إثارة جنسية",
    "erotic thriller television programmes": "برامج تلفزيونية إثارة جنسية",
    "erotic thriller television programs": "برامج تلفزيونية إثارة جنسية",
    "erotic thriller television series": "مسلسلات تلفزيونية إثارة جنسية",
    "erotic thriller video games": "ألعاب فيديو إثارة جنسية",
    "erotic thriller web series": "مسلسلات ويب إثارة جنسية",
    "erotic video games": "ألعاب فيديو إغرائية",
    "erotic web series": "مسلسلات ويب إغرائية",
    "experimental comics": "قصص مصورة تجريبية",
    "experimental film series": "سلاسل أفلام تجريبية",
    "experimental soap opera": "مسلسلات طويلة تجريبية",
    "experimental television episodes": "حلقات تلفزيونية تجريبية",
    "experimental television films": "أفلام تلفزيونية تجريبية",
    "experimental television miniseries": "مسلسلات قصيرة تلفزيونية تجريبية",
    "experimental television news": "أخبار تلفزيونية تجريبية",
    "experimental television programmes": "برامج تلفزيونية تجريبية",
    "experimental television programs": "برامج تلفزيونية تجريبية",
    "experimental television series": "مسلسلات تلفزيونية تجريبية",
    "experimental video games": "ألعاب فيديو تجريبية",
    "experimental web series": "مسلسلات ويب تجريبية",
    "exploitation comics": "قصص مصورة استغلالية",
    "exploitation film series": "سلاسل أفلام استغلالية",
    "exploitation soap opera": "مسلسلات طويلة استغلالية",
    "exploitation television episodes": "حلقات تلفزيونية استغلالية",
    "exploitation television films": "أفلام تلفزيونية استغلالية",
    "exploitation television miniseries": "مسلسلات قصيرة تلفزيونية استغلالية",
    "exploitation television news": "أخبار تلفزيونية استغلالية",
    "exploitation television programmes": "برامج تلفزيونية استغلالية",
    "exploitation television programs": "برامج تلفزيونية استغلالية",
    "exploitation television series": "مسلسلات تلفزيونية استغلالية",
    "exploitation video games": "ألعاب فيديو استغلالية",
    "exploitation web series": "مسلسلات ويب استغلالية",
    "family comics": "قصص مصورة عائلية",
    "family film series": "سلاسل أفلام عائلية",
    "family soap opera": "مسلسلات طويلة عائلية",
    "family television episodes": "حلقات تلفزيونية عائلية",
    "family television films": "أفلام تلفزيونية عائلية",
    "family television miniseries": "مسلسلات قصيرة تلفزيونية عائلية",
    "family television news": "أخبار تلفزيونية عائلية",
    "family television programmes": "برامج تلفزيونية عائلية",
    "family television programs": "برامج تلفزيونية عائلية",
    "family television series": "مسلسلات تلفزيونية عائلية",
    "family video games": "ألعاب فيديو عائلية",
    "family web series": "مسلسلات ويب عائلية",
    "fan comics": "قصص مصورة معجبين",
    "fan film series": "سلاسل أفلام معجبين",
    "fan soap opera": "مسلسلات طويلة معجبين",
    "fan television episodes": "حلقات تلفزيونية معجبين",
    "fan television films": "أفلام تلفزيونية معجبين",
    "fan television miniseries": "مسلسلات قصيرة تلفزيونية معجبين",
    "fan television news": "أخبار تلفزيونية معجبين",
    "fan television programmes": "برامج تلفزيونية معجبين",
    "fan television programs": "برامج تلفزيونية معجبين",
    "fan television series": "مسلسلات تلفزيونية معجبين",
    "fan video games": "ألعاب فيديو معجبين",
    "fan web series": "مسلسلات ويب معجبين",
    "fantasy comics": "قصص مصورة فانتازيا",
    "fantasy film series": "سلاسل أفلام فانتازيا",
    "fantasy films": "أفلام فانتازيا",
    "fantasy soap opera": "مسلسلات طويلة فانتازيا",
    "fantasy television episodes": "حلقات تلفزيونية فانتازيا",
    "fantasy television films": "أفلام تلفزيونية فانتازيا",
    "fantasy television miniseries": "مسلسلات قصيرة تلفزيونية فانتازيا",
    "fantasy television news": "أخبار تلفزيونية فانتازيا",
    "fantasy television programmes": "برامج تلفزيونية فانتازيا",
    "fantasy television programs": "برامج تلفزيونية فانتازيا",
    "fantasy television series": "مسلسلات تلفزيونية فانتازيا",
    "fantasy video games": "ألعاب فيديو فانتازيا",
    "fantasy web series": "مسلسلات ويب فانتازيا",
    "feature comics": "قصص مصورة طويلة",
    "feature film series": "سلاسل أفلام طويلة",
    "feature soap opera": "مسلسلات طويلة طويلة",
    "feature television episodes": "حلقات تلفزيونية طويلة",
    "feature television films": "أفلام تلفزيونية طويلة",
    "feature television miniseries": "مسلسلات قصيرة تلفزيونية طويلة",
    "feature television news": "أخبار تلفزيونية طويلة",
    "feature television programmes": "برامج تلفزيونية طويلة",
    "feature television programs": "برامج تلفزيونية طويلة",
    "feature television series": "مسلسلات تلفزيونية طويلة",
    "feature video games": "ألعاب فيديو طويلة",
    "feature web series": "مسلسلات ويب طويلة",
    "female buddy comics": "قصص مصورة رفيقات",
    "female buddy film series": "سلاسل أفلام رفيقات",
    "female buddy soap opera": "مسلسلات طويلة رفيقات",
    "female buddy television episodes": "حلقات تلفزيونية رفيقات",
    "female buddy television films": "أفلام تلفزيونية رفيقات",
    "female buddy television miniseries": "مسلسلات قصيرة تلفزيونية رفيقات",
    "female buddy television news": "أخبار تلفزيونية رفيقات",
    "female buddy television programmes": "برامج تلفزيونية رفيقات",
    "female buddy television programs": "برامج تلفزيونية رفيقات",
    "female buddy television series": "مسلسلات تلفزيونية رفيقات",
    "female buddy video games": "ألعاب فيديو رفيقات",
    "female buddy web series": "مسلسلات ويب رفيقات",
    "feminist comics": "قصص مصورة نسوية",
    "feminist film series": "سلاسل أفلام نسوية",
    "feminist soap opera": "مسلسلات طويلة نسوية",
    "feminist television episodes": "حلقات تلفزيونية نسوية",
    "feminist television films": "أفلام تلفزيونية نسوية",
    "feminist television miniseries": "مسلسلات قصيرة تلفزيونية نسوية",
    "feminist television news": "أخبار تلفزيونية نسوية",
    "feminist television programmes": "برامج تلفزيونية نسوية",
    "feminist television programs": "برامج تلفزيونية نسوية",
    "feminist television series": "مسلسلات تلفزيونية نسوية",
    "feminist video games": "ألعاب فيديو نسوية",
    "feminist web series": "مسلسلات ويب نسوية",
    "fiction comics": "قصص مصورة خيالية",
    "fiction film series": "سلاسل أفلام خيالية",
    "fiction soap opera": "مسلسلات طويلة خيالية",
    "fiction television episodes": "حلقات تلفزيونية خيالية",
    "fiction television films": "أفلام تلفزيونية خيالية",
    "fiction television miniseries": "مسلسلات قصيرة تلفزيونية خيالية",
    "fiction television news": "أخبار تلفزيونية خيالية",
    "fiction television programmes": "برامج تلفزيونية خيالية",
    "fiction television programs": "برامج تلفزيونية خيالية",
    "fiction television series": "مسلسلات تلفزيونية خيالية",
    "fiction video games": "ألعاب فيديو خيالية",
    "fiction web series": "مسلسلات ويب خيالية",
    "final fantasy comics": "قصص مصورة فاينل فانتازي",
    "final fantasy film series": "سلاسل أفلام فاينل فانتازي",
    "final fantasy soap opera": "مسلسلات طويلة فاينل فانتازي",
    "final fantasy television episodes": "حلقات تلفزيونية فاينل فانتازي",
    "final fantasy television films": "أفلام تلفزيونية فاينل فانتازي",
    "final fantasy television miniseries": "مسلسلات قصيرة تلفزيونية فاينل فانتازي",
    "final fantasy television news": "أخبار تلفزيونية فاينل فانتازي",
    "final fantasy television programmes": "برامج تلفزيونية فاينل فانتازي",
    "final fantasy television programs": "برامج تلفزيونية فاينل فانتازي",
    "final fantasy television series": "مسلسلات تلفزيونية فاينل فانتازي",
    "final fantasy video games": "ألعاب فيديو فاينل فانتازي",
    "final fantasy web series": "مسلسلات ويب فاينل فانتازي",
    "flashback comics": "قصص مصورة استرجاع",
    "flashback film series": "سلاسل أفلام استرجاع",
    "flashback soap opera": "مسلسلات طويلة استرجاع",
    "flashback television episodes": "حلقات تلفزيونية استرجاع",
    "flashback television films": "أفلام تلفزيونية استرجاع",
    "flashback television miniseries": "مسلسلات قصيرة تلفزيونية استرجاع",
    "flashback television news": "أخبار تلفزيونية استرجاع",
    "flashback television programmes": "برامج تلفزيونية استرجاع",
    "flashback television programs": "برامج تلفزيونية استرجاع",
    "flashback television series": "مسلسلات تلفزيونية استرجاع",
    "flashback video games": "ألعاب فيديو استرجاع",
    "flashback web series": "مسلسلات ويب استرجاع",
    "found footage comics": "قصص مصورة تسجيلات مكتشفة",
    "found footage film series": "سلاسل أفلام تسجيلات مكتشفة",
    "found footage soap opera": "مسلسلات طويلة تسجيلات مكتشفة",
    "found footage television episodes": "حلقات تلفزيونية تسجيلات مكتشفة",
    "found footage television films": "أفلام تلفزيونية تسجيلات مكتشفة",
    "found footage television miniseries": "مسلسلات قصيرة تلفزيونية تسجيلات مكتشفة",
    "found footage television news": "أخبار تلفزيونية تسجيلات مكتشفة",
    "found footage television programmes": "برامج تلفزيونية تسجيلات مكتشفة",
    "found footage television programs": "برامج تلفزيونية تسجيلات مكتشفة",
    "found footage television series": "مسلسلات تلفزيونية تسجيلات مكتشفة",
    "found footage video games": "ألعاب فيديو تسجيلات مكتشفة",
    "found footage web series": "مسلسلات ويب تسجيلات مكتشفة",
    "free cinema comics": "قصص مصورة سينما حرة",
    "free cinema film series": "سلاسل أفلام سينما حرة",
    "free cinema soap opera": "مسلسلات طويلة سينما حرة",
    "free cinema television episodes": "حلقات تلفزيونية سينما حرة",
    "free cinema television films": "أفلام تلفزيونية سينما حرة",
    "free cinema television miniseries": "مسلسلات قصيرة تلفزيونية سينما حرة",
    "free cinema television news": "أخبار تلفزيونية سينما حرة",
    "free cinema television programmes": "برامج تلفزيونية سينما حرة",
    "free cinema television programs": "برامج تلفزيونية سينما حرة",
    "free cinema television series": "مسلسلات تلفزيونية سينما حرة",
    "free cinema video games": "ألعاب فيديو سينما حرة",
    "free cinema web series": "مسلسلات ويب سينما حرة",
    "gangster comics": "قصص مصورة عصابات",
    "gangster film series": "سلاسل أفلام عصابات",
    "gangster soap opera": "مسلسلات طويلة عصابات",
    "gangster television episodes": "حلقات تلفزيونية عصابات",
    "gangster television films": "أفلام تلفزيونية عصابات",
    "gangster television miniseries": "مسلسلات قصيرة تلفزيونية عصابات",
    "gangster television news": "أخبار تلفزيونية عصابات",
    "gangster television programmes": "برامج تلفزيونية عصابات",
    "gangster television programs": "برامج تلفزيونية عصابات",
    "gangster television series": "مسلسلات تلفزيونية عصابات",
    "gangster video games": "ألعاب فيديو عصابات",
    "gangster web series": "مسلسلات ويب عصابات",
    "girls with guns comics": "قصص مصورة فتيات مع أسلحة",
    "girls with guns film series": "سلاسل أفلام فتيات مع أسلحة",
    "girls with guns soap opera": "مسلسلات طويلة فتيات مع أسلحة",
    "girls with guns television episodes": "حلقات تلفزيونية فتيات مع أسلحة",
    "girls with guns television films": "أفلام تلفزيونية فتيات مع أسلحة",
    "girls with guns television miniseries": "مسلسلات قصيرة تلفزيونية فتيات مع أسلحة",
    "girls with guns television news": "أخبار تلفزيونية فتيات مع أسلحة",
    "girls with guns television programmes": "برامج تلفزيونية فتيات مع أسلحة",
    "girls with guns television programs": "برامج تلفزيونية فتيات مع أسلحة",
    "girls with guns television series": "مسلسلات تلفزيونية فتيات مع أسلحة",
    "girls with guns video games": "ألعاب فيديو فتيات مع أسلحة",
    "girls with guns web series": "مسلسلات ويب فتيات مع أسلحة",
    "hacking comics": "قصص مصورة إختراق",
    "hacking film series": "سلاسل أفلام إختراق",
    "hacking soap opera": "مسلسلات طويلة إختراق",
    "hacking television episodes": "حلقات تلفزيونية إختراق",
    "hacking television films": "أفلام تلفزيونية إختراق",
    "hacking television miniseries": "مسلسلات قصيرة تلفزيونية إختراق",
    "hacking television news": "أخبار تلفزيونية إختراق",
    "hacking television programmes": "برامج تلفزيونية إختراق",
    "hacking television programs": "برامج تلفزيونية إختراق",
    "hacking television series": "مسلسلات تلفزيونية إختراق",
    "hacking video games": "ألعاب فيديو إختراق",
    "hacking web series": "مسلسلات ويب إختراق",
    "heist comics": "قصص مصورة سرقة",
    "heist film series": "سلاسل أفلام سرقة",
    "heist soap opera": "مسلسلات طويلة سرقة",
    "heist television episodes": "حلقات تلفزيونية سرقة",
    "heist television films": "أفلام تلفزيونية سرقة",
    "heist television miniseries": "مسلسلات قصيرة تلفزيونية سرقة",
    "heist television news": "أخبار تلفزيونية سرقة",
    "heist television programmes": "برامج تلفزيونية سرقة",
    "heist television programs": "برامج تلفزيونية سرقة",
    "heist television series": "مسلسلات تلفزيونية سرقة",
    "heist video games": "ألعاب فيديو سرقة",
    "heist web series": "مسلسلات ويب سرقة",
    "historical comics": "قصص مصورة تاريخية",
    "historical film series": "سلاسل أفلام تاريخية",
    "historical soap opera": "مسلسلات طويلة تاريخية",
    "historical television episodes": "حلقات تلفزيونية تاريخية",
    "historical television films": "أفلام تلفزيونية تاريخية",
    "historical television miniseries": "مسلسلات قصيرة تلفزيونية تاريخية",
    "historical television news": "أخبار تلفزيونية تاريخية",
    "historical television programmes": "برامج تلفزيونية تاريخية",
    "historical television programs": "برامج تلفزيونية تاريخية",
    "historical television series": "مسلسلات تلفزيونية تاريخية",
    "historical video games": "ألعاب فيديو تاريخية",
    "historical web series": "مسلسلات ويب تاريخية",
    "hood comics": "قصص مصورة هود",
    "hood film series": "سلاسل أفلام هود",
    "hood soap opera": "مسلسلات طويلة هود",
    "hood television episodes": "حلقات تلفزيونية هود",
    "hood television films": "أفلام تلفزيونية هود",
    "hood television miniseries": "مسلسلات قصيرة تلفزيونية هود",
    "hood television news": "أخبار تلفزيونية هود",
    "hood television programmes": "برامج تلفزيونية هود",
    "hood television programs": "برامج تلفزيونية هود",
    "hood television series": "مسلسلات تلفزيونية هود",
    "hood video games": "ألعاب فيديو هود",
    "hood web series": "مسلسلات ويب هود",
    "horror comics": "قصص مصورة رعب",
    "horror film series": "سلاسل أفلام رعب",
    "horror films": "أفلام رعب",
    "horror soap opera": "مسلسلات طويلة رعب",
    "horror television episodes": "حلقات تلفزيونية رعب",
    "horror television films": "أفلام تلفزيونية رعب",
    "horror television miniseries": "مسلسلات قصيرة تلفزيونية رعب",
    "horror television news": "أخبار تلفزيونية رعب",
    "horror television programmes": "برامج تلفزيونية رعب",
    "horror television programs": "برامج تلفزيونية رعب",
    "horror television series": "مسلسلات تلفزيونية رعب",
    "horror video games": "ألعاب فيديو رعب",
    "horror web series": "مسلسلات ويب رعب",
    "independent comics": "قصص مصورة مستقلة",
    "independent film series": "سلاسل أفلام مستقلة",
    "independent soap opera": "مسلسلات طويلة مستقلة",
    "independent television episodes": "حلقات تلفزيونية مستقلة",
    "independent television films": "أفلام تلفزيونية مستقلة",
    "independent television miniseries": "مسلسلات قصيرة تلفزيونية مستقلة",
    "independent television news": "أخبار تلفزيونية مستقلة",
    "independent television programmes": "برامج تلفزيونية مستقلة",
    "independent television programs": "برامج تلفزيونية مستقلة",
    "independent television series": "مسلسلات تلفزيونية مستقلة",
    "independent video games": "ألعاب فيديو مستقلة",
    "independent web series": "مسلسلات ويب مستقلة",
    "interactive comics": "قصص مصورة تفاعلية",
    "interactive film series": "سلاسل أفلام تفاعلية",
    "interactive soap opera": "مسلسلات طويلة تفاعلية",
    "interactive television episodes": "حلقات تلفزيونية تفاعلية",
    "interactive television films": "أفلام تلفزيونية تفاعلية",
    "interactive television miniseries": "مسلسلات قصيرة تلفزيونية تفاعلية",
    "interactive television news": "أخبار تلفزيونية تفاعلية",
    "interactive television programmes": "برامج تلفزيونية تفاعلية",
    "interactive television programs": "برامج تلفزيونية تفاعلية",
    "interactive television series": "مسلسلات تلفزيونية تفاعلية",
    "interactive video games": "ألعاب فيديو تفاعلية",
    "interactive web series": "مسلسلات ويب تفاعلية",
    "internet comics": "قصص مصورة إنترنت",
    "internet film series": "سلاسل أفلام إنترنت",
    "internet soap opera": "مسلسلات طويلة إنترنت",
    "internet television episodes": "حلقات تلفزيونية إنترنت",
    "internet television films": "أفلام تلفزيونية إنترنت",
    "internet television miniseries": "مسلسلات قصيرة تلفزيونية إنترنت",
    "internet television news": "أخبار تلفزيونية إنترنت",
    "internet television programmes": "برامج تلفزيونية إنترنت",
    "internet television programs": "برامج تلفزيونية إنترنت",
    "internet television series": "مسلسلات تلفزيونية إنترنت",
    "internet video games": "ألعاب فيديو إنترنت",
    "internet web series": "مسلسلات ويب إنترنت",
    "joker comics": "قصص مصورة جوكر",
    "joker film series": "سلاسل أفلام جوكر",
    "joker soap opera": "مسلسلات طويلة جوكر",
    "joker television episodes": "حلقات تلفزيونية جوكر",
    "joker television films": "أفلام تلفزيونية جوكر",
    "joker television miniseries": "مسلسلات قصيرة تلفزيونية جوكر",
    "joker television news": "أخبار تلفزيونية جوكر",
    "joker television programmes": "برامج تلفزيونية جوكر",
    "joker television programs": "برامج تلفزيونية جوكر",
    "joker television series": "مسلسلات تلفزيونية جوكر",
    "joker video games": "ألعاب فيديو جوكر",
    "joker web series": "مسلسلات ويب جوكر",
    "kaiju comics": "قصص مصورة كايجو",
    "kaiju film series": "سلاسل أفلام كايجو",
    "kaiju soap opera": "مسلسلات طويلة كايجو",
    "kaiju television episodes": "حلقات تلفزيونية كايجو",
    "kaiju television films": "أفلام تلفزيونية كايجو",
    "kaiju television miniseries": "مسلسلات قصيرة تلفزيونية كايجو",
    "kaiju television news": "أخبار تلفزيونية كايجو",
    "kaiju television programmes": "برامج تلفزيونية كايجو",
    "kaiju television programs": "برامج تلفزيونية كايجو",
    "kaiju television series": "مسلسلات تلفزيونية كايجو",
    "kaiju video games": "ألعاب فيديو كايجو",
    "kaiju web series": "مسلسلات ويب كايجو",
    "kung fu comics": "قصص مصورة كونغ فو",
    "kung fu film series": "سلاسل أفلام كونغ فو",
    "kung fu soap opera": "مسلسلات طويلة كونغ فو",
    "kung fu television episodes": "حلقات تلفزيونية كونغ فو",
    "kung fu television films": "أفلام تلفزيونية كونغ فو",
    "kung fu television miniseries": "مسلسلات قصيرة تلفزيونية كونغ فو",
    "kung fu television news": "أخبار تلفزيونية كونغ فو",
    "kung fu television programmes": "برامج تلفزيونية كونغ فو",
    "kung fu television programs": "برامج تلفزيونية كونغ فو",
    "kung fu television series": "مسلسلات تلفزيونية كونغ فو",
    "kung fu video games": "ألعاب فيديو كونغ فو",
    "kung fu web series": "مسلسلات ويب كونغ فو",
    "latin comics": "قصص مصورة لاتينية",
    "latin film series": "سلاسل أفلام لاتينية",
    "latin soap opera": "مسلسلات طويلة لاتينية",
    "latin television episodes": "حلقات تلفزيونية لاتينية",
    "latin television films": "أفلام تلفزيونية لاتينية",
    "latin television miniseries": "مسلسلات قصيرة تلفزيونية لاتينية",
    "latin television news": "أخبار تلفزيونية لاتينية",
    "latin television programmes": "برامج تلفزيونية لاتينية",
    "latin television programs": "برامج تلفزيونية لاتينية",
    "latin television series": "مسلسلات تلفزيونية لاتينية",
    "latin video games": "ألعاب فيديو لاتينية",
    "latin web series": "مسلسلات ويب لاتينية",
    "legal comics": "قصص مصورة قانونية",
    "legal drama comics": "قصص مصورة دراما قانونية",
    "legal drama film series": "سلاسل أفلام دراما قانونية",
    "legal drama soap opera": "مسلسلات طويلة دراما قانونية",
    "legal drama television episodes": "حلقات تلفزيونية دراما قانونية",
    "legal drama television films": "أفلام تلفزيونية دراما قانونية",
    "legal drama television miniseries": "مسلسلات قصيرة تلفزيونية دراما قانونية",
    "legal drama television news": "أخبار تلفزيونية دراما قانونية",
    "legal drama television programmes": "برامج تلفزيونية دراما قانونية",
    "legal drama television programs": "برامج تلفزيونية دراما قانونية",
    "legal drama television series": "مسلسلات تلفزيونية دراما قانونية",
    "legal drama video games": "ألعاب فيديو دراما قانونية",
    "legal drama web series": "مسلسلات ويب دراما قانونية",
    "legal film series": "سلاسل أفلام قانونية",
    "legal soap opera": "مسلسلات طويلة قانونية",
    "legal television episodes": "حلقات تلفزيونية قانونية",
    "legal television films": "أفلام تلفزيونية قانونية",
    "legal television miniseries": "مسلسلات قصيرة تلفزيونية قانونية",
    "legal television news": "أخبار تلفزيونية قانونية",
    "legal television programmes": "برامج تلفزيونية قانونية",
    "legal television programs": "برامج تلفزيونية قانونية",
    "legal television series": "مسلسلات تلفزيونية قانونية",
    "legal thriller comics": "قصص مصورة إثارة قانونية",
    "legal thriller film series": "سلاسل أفلام إثارة قانونية",
    "legal thriller soap opera": "مسلسلات طويلة إثارة قانونية",
    "legal thriller television episodes": "حلقات تلفزيونية إثارة قانونية",
    "legal thriller television films": "أفلام تلفزيونية إثارة قانونية",
    "legal thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة قانونية",
    "legal thriller television news": "أخبار تلفزيونية إثارة قانونية",
    "legal thriller television programmes": "برامج تلفزيونية إثارة قانونية",
    "legal thriller television programs": "برامج تلفزيونية إثارة قانونية",
    "legal thriller television series": "مسلسلات تلفزيونية إثارة قانونية",
    "legal thriller video games": "ألعاب فيديو إثارة قانونية",
    "legal thriller web series": "مسلسلات ويب إثارة قانونية",
    "legal video games": "ألعاب فيديو قانونية",
    "legal web series": "مسلسلات ويب قانونية",
    "lgbt comics": "قصص مصورة إل جي بي تي",
    "lgbt film series": "سلاسل أفلام إل جي بي تي",
    "lgbt soap opera": "مسلسلات طويلة إل جي بي تي",
    "lgbt television episodes": "حلقات تلفزيونية إل جي بي تي",
    "lgbt television films": "أفلام تلفزيونية إل جي بي تي",
    "lgbt television miniseries": "مسلسلات قصيرة تلفزيونية إل جي بي تي",
    "lgbt television news": "أخبار تلفزيونية إل جي بي تي",
    "lgbt television programmes": "برامج تلفزيونية إل جي بي تي",
    "lgbt television programs": "برامج تلفزيونية إل جي بي تي",
    "lgbt television series": "مسلسلات تلفزيونية إل جي بي تي",
    "lgbt video games": "ألعاب فيديو إل جي بي تي",
    "lgbt web series": "مسلسلات ويب إل جي بي تي",
    "lgbtq comics": "قصص مصورة إل جي بي تي كيو",
    "lgbtq film series": "سلاسل أفلام إل جي بي تي كيو",
    "lgbtq soap opera": "مسلسلات طويلة إل جي بي تي كيو",
    "lgbtq television episodes": "حلقات تلفزيونية إل جي بي تي كيو",
    "lgbtq television films": "أفلام تلفزيونية إل جي بي تي كيو",
    "lgbtq television miniseries": "مسلسلات قصيرة تلفزيونية إل جي بي تي كيو",
    "lgbtq television news": "أخبار تلفزيونية إل جي بي تي كيو",
    "lgbtq television programmes": "برامج تلفزيونية إل جي بي تي كيو",
    "lgbtq television programs": "برامج تلفزيونية إل جي بي تي كيو",
    "lgbtq television series": "مسلسلات تلفزيونية إل جي بي تي كيو",
    "lgbtq video games": "ألعاب فيديو إل جي بي تي كيو",
    "lgbtq web series": "مسلسلات ويب إل جي بي تي كيو",
    "live comics": "قصص مصورة مباشرة",
    "live film series": "سلاسل أفلام مباشرة",
    "live soap opera": "مسلسلات طويلة مباشرة",
    "live television episodes": "حلقات تلفزيونية مباشرة",
    "live television films": "أفلام تلفزيونية مباشرة",
    "live television miniseries": "مسلسلات قصيرة تلفزيونية مباشرة",
    "live television news": "أخبار تلفزيونية مباشرة",
    "live television programmes": "برامج تلفزيونية مباشرة",
    "live television programs": "برامج تلفزيونية مباشرة",
    "live television series": "مسلسلات تلفزيونية مباشرة",
    "live video games": "ألعاب فيديو مباشرة",
    "live web series": "مسلسلات ويب مباشرة",
    "lost comics": "قصص مصورة مفقودة",
    "lost film series": "سلاسل أفلام مفقودة",
    "lost soap opera": "مسلسلات طويلة مفقودة",
    "lost television episodes": "حلقات تلفزيونية مفقودة",
    "lost television films": "أفلام تلفزيونية مفقودة",
    "lost television miniseries": "مسلسلات قصيرة تلفزيونية مفقودة",
    "lost television news": "أخبار تلفزيونية مفقودة",
    "lost television programmes": "برامج تلفزيونية مفقودة",
    "lost television programs": "برامج تلفزيونية مفقودة",
    "lost television series": "مسلسلات تلفزيونية مفقودة",
    "lost video games": "ألعاب فيديو مفقودة",
    "lost web series": "مسلسلات ويب مفقودة",
    "mafia comics": "قصص مصورة مافيا",
    "mafia film series": "سلاسل أفلام مافيا",
    "mafia soap opera": "مسلسلات طويلة مافيا",
    "mafia television episodes": "حلقات تلفزيونية مافيا",
    "mafia television films": "أفلام تلفزيونية مافيا",
    "mafia television miniseries": "مسلسلات قصيرة تلفزيونية مافيا",
    "mafia television news": "أخبار تلفزيونية مافيا",
    "mafia television programmes": "برامج تلفزيونية مافيا",
    "mafia television programs": "برامج تلفزيونية مافيا",
    "mafia television series": "مسلسلات تلفزيونية مافيا",
    "mafia video games": "ألعاب فيديو مافيا",
    "mafia web series": "مسلسلات ويب مافيا",
    "magic realism comics": "قصص مصورة واقعية سحرية",
    "magic realism film series": "سلاسل أفلام واقعية سحرية",
    "magic realism soap opera": "مسلسلات طويلة واقعية سحرية",
    "magic realism television episodes": "حلقات تلفزيونية واقعية سحرية",
    "magic realism television films": "أفلام تلفزيونية واقعية سحرية",
    "magic realism television miniseries": "مسلسلات قصيرة تلفزيونية واقعية سحرية",
    "magic realism television news": "أخبار تلفزيونية واقعية سحرية",
    "magic realism television programmes": "برامج تلفزيونية واقعية سحرية",
    "magic realism television programs": "برامج تلفزيونية واقعية سحرية",
    "magic realism television series": "مسلسلات تلفزيونية واقعية سحرية",
    "magic realism video games": "ألعاب فيديو واقعية سحرية",
    "magic realism web series": "مسلسلات ويب واقعية سحرية",
    "magical girl comics": "قصص مصورة فتاة ساحرة",
    "magical girl film series": "سلاسل أفلام فتاة ساحرة",
    "magical girl soap opera": "مسلسلات طويلة فتاة ساحرة",
    "magical girl television episodes": "حلقات تلفزيونية فتاة ساحرة",
    "magical girl television films": "أفلام تلفزيونية فتاة ساحرة",
    "magical girl television miniseries": "مسلسلات قصيرة تلفزيونية فتاة ساحرة",
    "magical girl television news": "أخبار تلفزيونية فتاة ساحرة",
    "magical girl television programmes": "برامج تلفزيونية فتاة ساحرة",
    "magical girl television programs": "برامج تلفزيونية فتاة ساحرة",
    "magical girl television series": "مسلسلات تلفزيونية فتاة ساحرة",
    "magical girl video games": "ألعاب فيديو فتاة ساحرة",
    "magical girl web series": "مسلسلات ويب فتاة ساحرة",
    "maritime comics": "قصص مصورة بحرية",
    "maritime film series": "سلاسل أفلام بحرية",
    "maritime soap opera": "مسلسلات طويلة بحرية",
    "maritime television episodes": "حلقات تلفزيونية بحرية",
    "maritime television films": "أفلام تلفزيونية بحرية",
    "maritime television miniseries": "مسلسلات قصيرة تلفزيونية بحرية",
    "maritime television news": "أخبار تلفزيونية بحرية",
    "maritime television programmes": "برامج تلفزيونية بحرية",
    "maritime television programs": "برامج تلفزيونية بحرية",
    "maritime television series": "مسلسلات تلفزيونية بحرية",
    "maritime video games": "ألعاب فيديو بحرية",
    "maritime web series": "مسلسلات ويب بحرية",
    "melodrama comics": "قصص مصورة ميلودراما",
    "melodrama film series": "سلاسل أفلام ميلودراما",
    "melodrama films": "أفلام ميلودراما",
    "melodrama soap opera": "مسلسلات طويلة ميلودراما",
    "melodrama television episodes": "حلقات تلفزيونية ميلودراما",
    "melodrama television films": "أفلام تلفزيونية ميلودراما",
    "melodrama television miniseries": "مسلسلات قصيرة تلفزيونية ميلودراما",
    "melodrama television news": "أخبار تلفزيونية ميلودراما",
    "melodrama television programmes": "برامج تلفزيونية ميلودراما",
    "melodrama television programs": "برامج تلفزيونية ميلودراما",
    "melodrama television series": "مسلسلات تلفزيونية ميلودراما",
    "melodrama video games": "ألعاب فيديو ميلودراما",
    "melodrama web series": "مسلسلات ويب ميلودراما",
    "metafictional comics": "قصص مصورة ما وراء القص",
    "metafictional film series": "سلاسل أفلام ما وراء القص",
    "metafictional soap opera": "مسلسلات طويلة ما وراء القص",
    "metafictional television episodes": "حلقات تلفزيونية ما وراء القص",
    "metafictional television films": "أفلام تلفزيونية ما وراء القص",
    "metafictional television miniseries": "مسلسلات قصيرة تلفزيونية ما وراء القص",
    "metafictional television news": "أخبار تلفزيونية ما وراء القص",
    "metafictional television programmes": "برامج تلفزيونية ما وراء القص",
    "metafictional television programs": "برامج تلفزيونية ما وراء القص",
    "metafictional television series": "مسلسلات تلفزيونية ما وراء القص",
    "metafictional video games": "ألعاب فيديو ما وراء القص",
    "metafictional web series": "مسلسلات ويب ما وراء القص",
    "military comics": "قصص مصورة عسكرية",
    "military film series": "سلاسل أفلام عسكرية",
    "military soap opera": "مسلسلات طويلة عسكرية",
    "military television episodes": "حلقات تلفزيونية عسكرية",
    "military television films": "أفلام تلفزيونية عسكرية",
    "military television miniseries": "مسلسلات قصيرة تلفزيونية عسكرية",
    "military television news": "أخبار تلفزيونية عسكرية",
    "military television programmes": "برامج تلفزيونية عسكرية",
    "military television programs": "برامج تلفزيونية عسكرية",
    "military television series": "مسلسلات تلفزيونية عسكرية",
    "military video games": "ألعاب فيديو عسكرية",
    "military web series": "مسلسلات ويب عسكرية",
    "mixtape comics": "قصص مصورة ميكستايب",
    "mixtape film series": "سلاسل أفلام ميكستايب",
    "mixtape soap opera": "مسلسلات طويلة ميكستايب",
    "mixtape television episodes": "حلقات تلفزيونية ميكستايب",
    "mixtape television films": "أفلام تلفزيونية ميكستايب",
    "mixtape television miniseries": "مسلسلات قصيرة تلفزيونية ميكستايب",
    "mixtape television news": "أخبار تلفزيونية ميكستايب",
    "mixtape television programmes": "برامج تلفزيونية ميكستايب",
    "mixtape television programs": "برامج تلفزيونية ميكستايب",
    "mixtape television series": "مسلسلات تلفزيونية ميكستايب",
    "mixtape video games": "ألعاب فيديو ميكستايب",
    "mixtape web series": "مسلسلات ويب ميكستايب",
    "mockumentary comics": "قصص مصورة وثائقية كاذبة",
    "mockumentary film series": "سلاسل أفلام وثائقية كاذبة",
    "mockumentary soap opera": "مسلسلات طويلة وثائقية كاذبة",
    "mockumentary television episodes": "حلقات تلفزيونية وثائقية كاذبة",
    "mockumentary television films": "أفلام تلفزيونية وثائقية كاذبة",
    "mockumentary television miniseries": "مسلسلات قصيرة تلفزيونية وثائقية كاذبة",
    "mockumentary television news": "أخبار تلفزيونية وثائقية كاذبة",
    "mockumentary television programmes": "برامج تلفزيونية وثائقية كاذبة",
    "mockumentary television programs": "برامج تلفزيونية وثائقية كاذبة",
    "mockumentary television series": "مسلسلات تلفزيونية وثائقية كاذبة",
    "mockumentary video games": "ألعاب فيديو وثائقية كاذبة",
    "mockumentary web series": "مسلسلات ويب وثائقية كاذبة",
    "monster comics": "قصص مصورة وحوش",
    "monster film series": "سلاسل أفلام وحوش",
    "monster soap opera": "مسلسلات طويلة وحوش",
    "monster television episodes": "حلقات تلفزيونية وحوش",
    "monster television films": "أفلام تلفزيونية وحوش",
    "monster television miniseries": "مسلسلات قصيرة تلفزيونية وحوش",
    "monster television news": "أخبار تلفزيونية وحوش",
    "monster television programmes": "برامج تلفزيونية وحوش",
    "monster television programs": "برامج تلفزيونية وحوش",
    "monster television series": "مسلسلات تلفزيونية وحوش",
    "monster video games": "ألعاب فيديو وحوش",
    "monster web series": "مسلسلات ويب وحوش",
    "music comics": "قصص مصورة موسيقية",
    "music film series": "سلاسل أفلام موسيقية",
    "music soap opera": "مسلسلات طويلة موسيقية",
    "music television episodes": "حلقات تلفزيونية موسيقية",
    "music television films": "أفلام تلفزيونية موسيقية",
    "music television miniseries": "مسلسلات قصيرة تلفزيونية موسيقية",
    "music television news": "أخبار تلفزيونية موسيقية",
    "music television programmes": "برامج تلفزيونية موسيقية",
    "music television programs": "برامج تلفزيونية موسيقية",
    "music television series": "مسلسلات تلفزيونية موسيقية",
    "music video games": "ألعاب فيديو موسيقية",
    "music web series": "مسلسلات ويب موسيقية",
    "musical comedy comics": "قصص مصورة كوميدية موسيقية",
    "musical comedy film series": "سلاسل أفلام كوميدية موسيقية",
    "musical comedy soap opera": "مسلسلات طويلة كوميدية موسيقية",
    "musical comedy television episodes": "حلقات تلفزيونية كوميدية موسيقية",
    "musical comedy television films": "أفلام تلفزيونية كوميدية موسيقية",
    "musical comedy television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية موسيقية",
    "musical comedy television news": "أخبار تلفزيونية كوميدية موسيقية",
    "musical comedy television programmes": "برامج تلفزيونية كوميدية موسيقية",
    "musical comedy television programs": "برامج تلفزيونية كوميدية موسيقية",
    "musical comedy television series": "مسلسلات تلفزيونية كوميدية موسيقية",
    "musical comedy video games": "ألعاب فيديو كوميدية موسيقية",
    "musical comedy web series": "مسلسلات ويب كوميدية موسيقية",
    "musical comics": "قصص مصورة موسيقية",
    "musical film series": "سلاسل أفلام موسيقية",
    "musical soap opera": "مسلسلات طويلة موسيقية",
    "musical television episodes": "حلقات تلفزيونية موسيقية",
    "musical television films": "أفلام تلفزيونية موسيقية",
    "musical television miniseries": "مسلسلات قصيرة تلفزيونية موسيقية",
    "musical television news": "أخبار تلفزيونية موسيقية",
    "musical television programmes": "برامج تلفزيونية موسيقية",
    "musical television programs": "برامج تلفزيونية موسيقية",
    "musical television series": "مسلسلات تلفزيونية موسيقية",
    "musical video games": "ألعاب فيديو موسيقية",
    "musical web series": "مسلسلات ويب موسيقية",
    "mystery comics": "قصص مصورة غموض",
    "mystery film series": "سلاسل أفلام غموض",
    "mystery soap opera": "مسلسلات طويلة غموض",
    "mystery television episodes": "حلقات تلفزيونية غموض",
    "mystery television films": "أفلام تلفزيونية غموض",
    "mystery television miniseries": "مسلسلات قصيرة تلفزيونية غموض",
    "mystery television news": "أخبار تلفزيونية غموض",
    "mystery television programmes": "برامج تلفزيونية غموض",
    "mystery television programs": "برامج تلفزيونية غموض",
    "mystery television series": "مسلسلات تلفزيونية غموض",
    "mystery video games": "ألعاب فيديو غموض",
    "mystery web series": "مسلسلات ويب غموض",
    "nature documentary comics": "قصص مصورة وثائقية برية",
    "nature documentary film series": "سلاسل أفلام وثائقية برية",
    "nature documentary soap opera": "مسلسلات طويلة وثائقية برية",
    "nature documentary television episodes": "حلقات تلفزيونية وثائقية برية",
    "nature documentary television films": "أفلام تلفزيونية وثائقية برية",
    "nature documentary television miniseries": "مسلسلات قصيرة تلفزيونية وثائقية برية",
    "nature documentary television news": "أخبار تلفزيونية وثائقية برية",
    "nature documentary television programmes": "برامج تلفزيونية وثائقية برية",
    "nature documentary television programs": "برامج تلفزيونية وثائقية برية",
    "nature documentary television series": "مسلسلات تلفزيونية وثائقية برية",
    "nature documentary video games": "ألعاب فيديو وثائقية برية",
    "nature documentary web series": "مسلسلات ويب وثائقية برية",
    "nautical comics": "قصص مصورة بحرية",
    "nautical film series": "سلاسل أفلام بحرية",
    "nautical soap opera": "مسلسلات طويلة بحرية",
    "nautical television episodes": "حلقات تلفزيونية بحرية",
    "nautical television films": "أفلام تلفزيونية بحرية",
    "nautical television miniseries": "مسلسلات قصيرة تلفزيونية بحرية",
    "nautical television news": "أخبار تلفزيونية بحرية",
    "nautical television programmes": "برامج تلفزيونية بحرية",
    "nautical television programs": "برامج تلفزيونية بحرية",
    "nautical television series": "مسلسلات تلفزيونية بحرية",
    "nautical video games": "ألعاب فيديو بحرية",
    "nautical web series": "مسلسلات ويب بحرية",
    "naval comics": "قصص مصورة بحرية عسكرية",
    "naval film series": "سلاسل أفلام بحرية عسكرية",
    "naval soap opera": "مسلسلات طويلة بحرية عسكرية",
    "naval television episodes": "حلقات تلفزيونية بحرية عسكرية",
    "naval television films": "أفلام تلفزيونية بحرية عسكرية",
    "naval television miniseries": "مسلسلات قصيرة تلفزيونية بحرية عسكرية",
    "naval television news": "أخبار تلفزيونية بحرية عسكرية",
    "naval television programmes": "برامج تلفزيونية بحرية عسكرية",
    "naval television programs": "برامج تلفزيونية بحرية عسكرية",
    "naval television series": "مسلسلات تلفزيونية بحرية عسكرية",
    "naval video games": "ألعاب فيديو بحرية عسكرية",
    "naval web series": "مسلسلات ويب بحرية عسكرية",
    "noir comics": "قصص مصورة نوار",
    "noir film series": "سلاسل أفلام نوار",
    "noir soap opera": "مسلسلات طويلة نوار",
    "noir television episodes": "حلقات تلفزيونية نوار",
    "noir television films": "أفلام تلفزيونية نوار",
    "noir television miniseries": "مسلسلات قصيرة تلفزيونية نوار",
    "noir television news": "أخبار تلفزيونية نوار",
    "noir television programmes": "برامج تلفزيونية نوار",
    "noir television programs": "برامج تلفزيونية نوار",
    "noir television series": "مسلسلات تلفزيونية نوار",
    "noir video games": "ألعاب فيديو نوار",
    "noir web series": "مسلسلات ويب نوار",
    "non fiction comics": "قصص مصورة غير خيالية",
    "non fiction film series": "سلاسل أفلام غير خيالية",
    "non fiction soap opera": "مسلسلات طويلة غير خيالية",
    "non fiction television episodes": "حلقات تلفزيونية غير خيالية",
    "non fiction television films": "أفلام تلفزيونية غير خيالية",
    "non fiction television miniseries": "مسلسلات قصيرة تلفزيونية غير خيالية",
    "non fiction television news": "أخبار تلفزيونية غير خيالية",
    "non fiction television programmes": "برامج تلفزيونية غير خيالية",
    "non fiction television programs": "برامج تلفزيونية غير خيالية",
    "non fiction television series": "مسلسلات تلفزيونية غير خيالية",
    "non fiction video games": "ألعاب فيديو غير خيالية",
    "non fiction web series": "مسلسلات ويب غير خيالية",
    "non narrative comics": "قصص مصورة غير سردية",
    "non narrative film series": "سلاسل أفلام غير سردية",
    "non narrative soap opera": "مسلسلات طويلة غير سردية",
    "non narrative television episodes": "حلقات تلفزيونية غير سردية",
    "non narrative television films": "أفلام تلفزيونية غير سردية",
    "non narrative television miniseries": "مسلسلات قصيرة تلفزيونية غير سردية",
    "non narrative television news": "أخبار تلفزيونية غير سردية",
    "non narrative television programmes": "برامج تلفزيونية غير سردية",
    "non narrative television programs": "برامج تلفزيونية غير سردية",
    "non narrative television series": "مسلسلات تلفزيونية غير سردية",
    "non narrative video games": "ألعاب فيديو غير سردية",
    "non narrative web series": "مسلسلات ويب غير سردية",
    "one man comics": "قصص مصورة رجل واحد",
    "one man film series": "سلاسل أفلام رجل واحد",
    "one man soap opera": "مسلسلات طويلة رجل واحد",
    "one man television episodes": "حلقات تلفزيونية رجل واحد",
    "one man television films": "أفلام تلفزيونية رجل واحد",
    "one man television miniseries": "مسلسلات قصيرة تلفزيونية رجل واحد",
    "one man television news": "أخبار تلفزيونية رجل واحد",
    "one man television programmes": "برامج تلفزيونية رجل واحد",
    "one man television programs": "برامج تلفزيونية رجل واحد",
    "one man television series": "مسلسلات تلفزيونية رجل واحد",
    "one man video games": "ألعاب فيديو رجل واحد",
    "one man web series": "مسلسلات ويب رجل واحد",
    "parody comics": "قصص مصورة ساخرة",
    "parody film series": "سلاسل أفلام ساخرة",
    "parody films": "أفلام ساخرة",
    "parody soap opera": "مسلسلات طويلة ساخرة",
    "parody television episodes": "حلقات تلفزيونية ساخرة",
    "parody television films": "أفلام تلفزيونية ساخرة",
    "parody television miniseries": "مسلسلات قصيرة تلفزيونية ساخرة",
    "parody television news": "أخبار تلفزيونية ساخرة",
    "parody television programmes": "برامج تلفزيونية ساخرة",
    "parody television programs": "برامج تلفزيونية ساخرة",
    "parody television series": "مسلسلات تلفزيونية ساخرة",
    "parody video games": "ألعاب فيديو ساخرة",
    "parody web series": "مسلسلات ويب ساخرة",
    "period comics": "قصص مصورة حقبية",
    "period film series": "سلاسل أفلام حقبية",
    "period soap opera": "مسلسلات طويلة حقبية",
    "period television episodes": "حلقات تلفزيونية حقبية",
    "period television films": "أفلام تلفزيونية حقبية",
    "period television miniseries": "مسلسلات قصيرة تلفزيونية حقبية",
    "period television news": "أخبار تلفزيونية حقبية",
    "period television programmes": "برامج تلفزيونية حقبية",
    "period television programs": "برامج تلفزيونية حقبية",
    "period television series": "مسلسلات تلفزيونية حقبية",
    "period video games": "ألعاب فيديو حقبية",
    "period web series": "مسلسلات ويب حقبية",
    "pirate comics": "قصص مصورة قراصنة",
    "pirate film series": "سلاسل أفلام قراصنة",
    "pirate soap opera": "مسلسلات طويلة قراصنة",
    "pirate television episodes": "حلقات تلفزيونية قراصنة",
    "pirate television films": "أفلام تلفزيونية قراصنة",
    "pirate television miniseries": "مسلسلات قصيرة تلفزيونية قراصنة",
    "pirate television news": "أخبار تلفزيونية قراصنة",
    "pirate television programmes": "برامج تلفزيونية قراصنة",
    "pirate television programs": "برامج تلفزيونية قراصنة",
    "pirate television series": "مسلسلات تلفزيونية قراصنة",
    "pirate video games": "ألعاب فيديو قراصنة",
    "pirate web series": "مسلسلات ويب قراصنة",
    "police procedural comics": "قصص مصورة إجراءات الشرطة",
    "police procedural film series": "سلاسل أفلام إجراءات الشرطة",
    "police procedural films": "أفلام إجراءات الشرطة",
    "police procedural soap opera": "مسلسلات طويلة إجراءات الشرطة",
    "police procedural television episodes": "حلقات تلفزيونية إجراءات الشرطة",
    "police procedural television films": "أفلام تلفزيونية إجراءات الشرطة",
    "police procedural television miniseries": "مسلسلات قصيرة تلفزيونية إجراءات الشرطة",
    "police procedural television news": "أخبار تلفزيونية إجراءات الشرطة",
    "police procedural television programmes": "برامج تلفزيونية إجراءات الشرطة",
    "police procedural television programs": "برامج تلفزيونية إجراءات الشرطة",
    "police procedural television series": "مسلسلات تلفزيونية إجراءات الشرطة",
    "police procedural video games": "ألعاب فيديو إجراءات الشرطة",
    "police procedural web series": "مسلسلات ويب إجراءات الشرطة",
    "political cinema comics": "قصص مصورة سينما سياسية",
    "political cinema film series": "سلاسل أفلام سينما سياسية",
    "political cinema soap opera": "مسلسلات طويلة سينما سياسية",
    "political cinema television episodes": "حلقات تلفزيونية سينما سياسية",
    "political cinema television films": "أفلام تلفزيونية سينما سياسية",
    "political cinema television miniseries": "مسلسلات قصيرة تلفزيونية سينما سياسية",
    "political cinema television news": "أخبار تلفزيونية سينما سياسية",
    "political cinema television programmes": "برامج تلفزيونية سينما سياسية",
    "political cinema television programs": "برامج تلفزيونية سينما سياسية",
    "political cinema television series": "مسلسلات تلفزيونية سينما سياسية",
    "political cinema video games": "ألعاب فيديو سينما سياسية",
    "political cinema web series": "مسلسلات ويب سينما سياسية",
    "political comics": "قصص مصورة سياسية",
    "political fiction comics": "قصص مصورة خيالية سياسية",
    "political fiction film series": "سلاسل أفلام خيالية سياسية",
    "political fiction soap opera": "مسلسلات طويلة خيالية سياسية",
    "political fiction television episodes": "حلقات تلفزيونية خيالية سياسية",
    "political fiction television films": "أفلام تلفزيونية خيالية سياسية",
    "political fiction television miniseries": "مسلسلات قصيرة تلفزيونية خيالية سياسية",
    "political fiction television news": "أخبار تلفزيونية خيالية سياسية",
    "political fiction television programmes": "برامج تلفزيونية خيالية سياسية",
    "political fiction television programs": "برامج تلفزيونية خيالية سياسية",
    "political fiction television series": "مسلسلات تلفزيونية خيالية سياسية",
    "political fiction video games": "ألعاب فيديو خيالية سياسية",
    "political fiction web series": "مسلسلات ويب خيالية سياسية",
    "political film series": "سلاسل أفلام سياسية",
    "political soap opera": "مسلسلات طويلة سياسية",
    "political television episodes": "حلقات تلفزيونية سياسية",
    "political television films": "أفلام تلفزيونية سياسية",
    "political television miniseries": "مسلسلات قصيرة تلفزيونية سياسية",
    "political television news": "أخبار تلفزيونية سياسية",
    "political television programmes": "برامج تلفزيونية سياسية",
    "political television programs": "برامج تلفزيونية سياسية",
    "political television series": "مسلسلات تلفزيونية سياسية",
    "political thriller comics": "قصص مصورة إثارة سياسية",
    "political thriller film series": "سلاسل أفلام إثارة سياسية",
    "political thriller soap opera": "مسلسلات طويلة إثارة سياسية",
    "political thriller television episodes": "حلقات تلفزيونية إثارة سياسية",
    "political thriller television films": "أفلام تلفزيونية إثارة سياسية",
    "political thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة سياسية",
    "political thriller television news": "أخبار تلفزيونية إثارة سياسية",
    "political thriller television programmes": "برامج تلفزيونية إثارة سياسية",
    "political thriller television programs": "برامج تلفزيونية إثارة سياسية",
    "political thriller television series": "مسلسلات تلفزيونية إثارة سياسية",
    "political thriller video games": "ألعاب فيديو إثارة سياسية",
    "political thriller web series": "مسلسلات ويب إثارة سياسية",
    "political video games": "ألعاب فيديو سياسية",
    "political web series": "مسلسلات ويب سياسية",
    "porno comics": "قصص مصورة إباحية",
    "porno film series": "سلاسل أفلام إباحية",
    "porno soap opera": "مسلسلات طويلة إباحية",
    "porno television episodes": "حلقات تلفزيونية إباحية",
    "porno television films": "أفلام تلفزيونية إباحية",
    "porno television miniseries": "مسلسلات قصيرة تلفزيونية إباحية",
    "porno television news": "أخبار تلفزيونية إباحية",
    "porno television programmes": "برامج تلفزيونية إباحية",
    "porno television programs": "برامج تلفزيونية إباحية",
    "porno television series": "مسلسلات تلفزيونية إباحية",
    "porno video games": "ألعاب فيديو إباحية",
    "porno web series": "مسلسلات ويب إباحية",
    "pornographic comics": "قصص مصورة إباحية",
    "pornographic film series": "سلاسل أفلام إباحية",
    "pornographic soap opera": "مسلسلات طويلة إباحية",
    "pornographic television episodes": "حلقات تلفزيونية إباحية",
    "pornographic television films": "أفلام تلفزيونية إباحية",
    "pornographic television miniseries": "مسلسلات قصيرة تلفزيونية إباحية",
    "pornographic television news": "أخبار تلفزيونية إباحية",
    "pornographic television programmes": "برامج تلفزيونية إباحية",
    "pornographic television programs": "برامج تلفزيونية إباحية",
    "pornographic television series": "مسلسلات تلفزيونية إباحية",
    "pornographic video games": "ألعاب فيديو إباحية",
    "pornographic web series": "مسلسلات ويب إباحية",
    "prequel comics": "قصص مصورة بادئة",
    "prequel film series": "سلاسل أفلام بادئة",
    "prequel soap opera": "مسلسلات طويلة بادئة",
    "prequel television episodes": "حلقات تلفزيونية بادئة",
    "prequel television films": "أفلام تلفزيونية بادئة",
    "prequel television miniseries": "مسلسلات قصيرة تلفزيونية بادئة",
    "prequel television news": "أخبار تلفزيونية بادئة",
    "prequel television programmes": "برامج تلفزيونية بادئة",
    "prequel television programs": "برامج تلفزيونية بادئة",
    "prequel television series": "مسلسلات تلفزيونية بادئة",
    "prequel video games": "ألعاب فيديو بادئة",
    "prequel web series": "مسلسلات ويب بادئة",
    "propaganda comics": "قصص مصورة دعائية",
    "propaganda film series": "سلاسل أفلام دعائية",
    "propaganda soap opera": "مسلسلات طويلة دعائية",
    "propaganda television episodes": "حلقات تلفزيونية دعائية",
    "propaganda television films": "أفلام تلفزيونية دعائية",
    "propaganda television miniseries": "مسلسلات قصيرة تلفزيونية دعائية",
    "propaganda television news": "أخبار تلفزيونية دعائية",
    "propaganda television programmes": "برامج تلفزيونية دعائية",
    "propaganda television programs": "برامج تلفزيونية دعائية",
    "propaganda television series": "مسلسلات تلفزيونية دعائية",
    "propaganda video games": "ألعاب فيديو دعائية",
    "propaganda web series": "مسلسلات ويب دعائية",
    "psychological comics": "قصص مصورة نفسية",
    "psychological film series": "سلاسل أفلام نفسية",
    "psychological horror comics": "قصص مصورة رعب نفسي",
    "psychological horror film series": "سلاسل أفلام رعب نفسي",
    "psychological horror soap opera": "مسلسلات طويلة رعب نفسي",
    "psychological horror television episodes": "حلقات تلفزيونية رعب نفسي",
    "psychological horror television films": "أفلام تلفزيونية رعب نفسي",
    "psychological horror television miniseries": "مسلسلات قصيرة تلفزيونية رعب نفسي",
    "psychological horror television news": "أخبار تلفزيونية رعب نفسي",
    "psychological horror television programmes": "برامج تلفزيونية رعب نفسي",
    "psychological horror television programs": "برامج تلفزيونية رعب نفسي",
    "psychological horror television series": "مسلسلات تلفزيونية رعب نفسي",
    "psychological horror video games": "ألعاب فيديو رعب نفسي",
    "psychological horror web series": "مسلسلات ويب رعب نفسي",
    "psychological soap opera": "مسلسلات طويلة نفسية",
    "psychological television episodes": "حلقات تلفزيونية نفسية",
    "psychological television films": "أفلام تلفزيونية نفسية",
    "psychological television miniseries": "مسلسلات قصيرة تلفزيونية نفسية",
    "psychological television news": "أخبار تلفزيونية نفسية",
    "psychological television programmes": "برامج تلفزيونية نفسية",
    "psychological television programs": "برامج تلفزيونية نفسية",
    "psychological television series": "مسلسلات تلفزيونية نفسية",
    "psychological thriller comics": "قصص مصورة إثارة نفسية",
    "psychological thriller film series": "سلاسل أفلام إثارة نفسية",
    "psychological thriller soap opera": "مسلسلات طويلة إثارة نفسية",
    "psychological thriller television episodes": "حلقات تلفزيونية إثارة نفسية",
    "psychological thriller television films": "أفلام تلفزيونية إثارة نفسية",
    "psychological thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة نفسية",
    "psychological thriller television news": "أخبار تلفزيونية إثارة نفسية",
    "psychological thriller television programmes": "برامج تلفزيونية إثارة نفسية",
    "psychological thriller television programs": "برامج تلفزيونية إثارة نفسية",
    "psychological thriller television series": "مسلسلات تلفزيونية إثارة نفسية",
    "psychological thriller video games": "ألعاب فيديو إثارة نفسية",
    "psychological thriller web series": "مسلسلات ويب إثارة نفسية",
    "psychological video games": "ألعاب فيديو نفسية",
    "psychological web series": "مسلسلات ويب نفسية",
    "reality comics": "قصص مصورة واقعية",
    "reality film series": "سلاسل أفلام واقعية",
    "reality soap opera": "مسلسلات طويلة واقعية",
    "reality television episodes": "حلقات تلفزيونية واقعية",
    "reality television films": "أفلام تلفزيونية واقعية",
    "reality television miniseries": "مسلسلات قصيرة تلفزيونية واقعية",
    "reality television news": "أخبار تلفزيونية واقعية",
    "reality television programmes": "برامج تلفزيونية واقعية",
    "reality television programs": "برامج تلفزيونية واقعية",
    "reality television series": "مسلسلات تلفزيونية واقعية",
    "reality video games": "ألعاب فيديو واقعية",
    "reality web series": "مسلسلات ويب واقعية",
    "reboot comics": "قصص مصورة ريبوت",
    "reboot film series": "سلاسل أفلام ريبوت",
    "reboot soap opera": "مسلسلات طويلة ريبوت",
    "reboot television episodes": "حلقات تلفزيونية ريبوت",
    "reboot television films": "أفلام تلفزيونية ريبوت",
    "reboot television miniseries": "مسلسلات قصيرة تلفزيونية ريبوت",
    "reboot television news": "أخبار تلفزيونية ريبوت",
    "reboot television programmes": "برامج تلفزيونية ريبوت",
    "reboot television programs": "برامج تلفزيونية ريبوت",
    "reboot television series": "مسلسلات تلفزيونية ريبوت",
    "reboot video games": "ألعاب فيديو ريبوت",
    "reboot web series": "مسلسلات ويب ريبوت",
    "rediscovered comics": "قصص مصورة اكتشاف",
    "rediscovered film series": "سلاسل أفلام اكتشاف",
    "rediscovered soap opera": "مسلسلات طويلة اكتشاف",
    "rediscovered television episodes": "حلقات تلفزيونية اكتشاف",
    "rediscovered television films": "أفلام تلفزيونية اكتشاف",
    "rediscovered television miniseries": "مسلسلات قصيرة تلفزيونية اكتشاف",
    "rediscovered television news": "أخبار تلفزيونية اكتشاف",
    "rediscovered television programmes": "برامج تلفزيونية اكتشاف",
    "rediscovered television programs": "برامج تلفزيونية اكتشاف",
    "rediscovered television series": "مسلسلات تلفزيونية اكتشاف",
    "rediscovered video games": "ألعاب فيديو اكتشاف",
    "rediscovered web series": "مسلسلات ويب اكتشاف",
    "religious comics": "قصص مصورة دينية",
    "religious film series": "سلاسل أفلام دينية",
    "religious soap opera": "مسلسلات طويلة دينية",
    "religious television episodes": "حلقات تلفزيونية دينية",
    "religious television films": "أفلام تلفزيونية دينية",
    "religious television miniseries": "مسلسلات قصيرة تلفزيونية دينية",
    "religious television news": "أخبار تلفزيونية دينية",
    "religious television programmes": "برامج تلفزيونية دينية",
    "religious television programs": "برامج تلفزيونية دينية",
    "religious television series": "مسلسلات تلفزيونية دينية",
    "religious video games": "ألعاب فيديو دينية",
    "religious web series": "مسلسلات ويب دينية",
    "remix comics": "قصص مصورة ريمكس",
    "remix film series": "سلاسل أفلام ريمكس",
    "remix soap opera": "مسلسلات طويلة ريمكس",
    "remix television episodes": "حلقات تلفزيونية ريمكس",
    "remix television films": "أفلام تلفزيونية ريمكس",
    "remix television miniseries": "مسلسلات قصيرة تلفزيونية ريمكس",
    "remix television news": "أخبار تلفزيونية ريمكس",
    "remix television programmes": "برامج تلفزيونية ريمكس",
    "remix television programs": "برامج تلفزيونية ريمكس",
    "remix television series": "مسلسلات تلفزيونية ريمكس",
    "remix video games": "ألعاب فيديو ريمكس",
    "remix web series": "مسلسلات ويب ريمكس",
    "reportage comics": "قصص مصورة تقرير",
    "reportage film series": "سلاسل أفلام تقرير",
    "reportage soap opera": "مسلسلات طويلة تقرير",
    "reportage television episodes": "حلقات تلفزيونية تقرير",
    "reportage television films": "أفلام تلفزيونية تقرير",
    "reportage television miniseries": "مسلسلات قصيرة تلفزيونية تقرير",
    "reportage television news": "أخبار تلفزيونية تقرير",
    "reportage television programmes": "برامج تلفزيونية تقرير",
    "reportage television programs": "برامج تلفزيونية تقرير",
    "reportage television series": "مسلسلات تلفزيونية تقرير",
    "reportage video games": "ألعاب فيديو تقرير",
    "reportage web series": "مسلسلات ويب تقرير",
    "robot comics": "قصص مصورة آلية",
    "robot film series": "سلاسل أفلام آلية",
    "robot soap opera": "مسلسلات طويلة آلية",
    "robot television episodes": "حلقات تلفزيونية آلية",
    "robot television films": "أفلام تلفزيونية آلية",
    "robot television miniseries": "مسلسلات قصيرة تلفزيونية آلية",
    "robot television news": "أخبار تلفزيونية آلية",
    "robot television programmes": "برامج تلفزيونية آلية",
    "robot television programs": "برامج تلفزيونية آلية",
    "robot television series": "مسلسلات تلفزيونية آلية",
    "robot video games": "ألعاب فيديو آلية",
    "robot web series": "مسلسلات ويب آلية",
    "rockumentary comics": "قصص مصورة وثائقي الروك",
    "rockumentary film series": "سلاسل أفلام وثائقي الروك",
    "rockumentary soap opera": "مسلسلات طويلة وثائقي الروك",
    "rockumentary television episodes": "حلقات تلفزيونية وثائقي الروك",
    "rockumentary television films": "أفلام تلفزيونية وثائقي الروك",
    "rockumentary television miniseries": "مسلسلات قصيرة تلفزيونية وثائقي الروك",
    "rockumentary television news": "أخبار تلفزيونية وثائقي الروك",
    "rockumentary television programmes": "برامج تلفزيونية وثائقي الروك",
    "rockumentary television programs": "برامج تلفزيونية وثائقي الروك",
    "rockumentary television series": "مسلسلات تلفزيونية وثائقي الروك",
    "rockumentary video games": "ألعاب فيديو وثائقي الروك",
    "rockumentary web series": "مسلسلات ويب وثائقي الروك",
    "romance comics": "قصص مصورة رومانسية",
    "romance film series": "سلاسل أفلام رومانسية",
    "romance soap opera": "مسلسلات طويلة رومانسية",
    "romance television episodes": "حلقات تلفزيونية رومانسية",
    "romance television films": "أفلام تلفزيونية رومانسية",
    "romance television miniseries": "مسلسلات قصيرة تلفزيونية رومانسية",
    "romance television news": "أخبار تلفزيونية رومانسية",
    "romance television programmes": "برامج تلفزيونية رومانسية",
    "romance television programs": "برامج تلفزيونية رومانسية",
    "romance television series": "مسلسلات تلفزيونية رومانسية",
    "romance video games": "ألعاب فيديو رومانسية",
    "romance web series": "مسلسلات ويب رومانسية",
    "romantic comedy comics": "قصص مصورة كوميدية رومانسية",
    "romantic comedy film series": "سلاسل أفلام كوميدية رومانسية",
    "romantic comedy soap opera": "مسلسلات طويلة كوميدية رومانسية",
    "romantic comedy television episodes": "حلقات تلفزيونية كوميدية رومانسية",
    "romantic comedy television films": "أفلام تلفزيونية كوميدية رومانسية",
    "romantic comedy television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية رومانسية",
    "romantic comedy television news": "أخبار تلفزيونية كوميدية رومانسية",
    "romantic comedy television programmes": "برامج تلفزيونية كوميدية رومانسية",
    "romantic comedy television programs": "برامج تلفزيونية كوميدية رومانسية",
    "romantic comedy television series": "مسلسلات تلفزيونية كوميدية رومانسية",
    "romantic comedy video games": "ألعاب فيديو كوميدية رومانسية",
    "romantic comedy web series": "مسلسلات ويب كوميدية رومانسية",
    "romantic comics": "قصص مصورة رومانسية",
    "romantic film series": "سلاسل أفلام رومانسية",
    "romantic soap opera": "مسلسلات طويلة رومانسية",
    "romantic television episodes": "حلقات تلفزيونية رومانسية",
    "romantic television films": "أفلام تلفزيونية رومانسية",
    "romantic television miniseries": "مسلسلات قصيرة تلفزيونية رومانسية",
    "romantic television news": "أخبار تلفزيونية رومانسية",
    "romantic television programmes": "برامج تلفزيونية رومانسية",
    "romantic television programs": "برامج تلفزيونية رومانسية",
    "romantic television series": "مسلسلات تلفزيونية رومانسية",
    "romantic video games": "ألعاب فيديو رومانسية",
    "romantic web series": "مسلسلات ويب رومانسية",
    "sailing comics": "قصص مصورة إبحار",
    "sailing film series": "سلاسل أفلام إبحار",
    "sailing soap opera": "مسلسلات طويلة إبحار",
    "sailing television episodes": "حلقات تلفزيونية إبحار",
    "sailing television films": "أفلام تلفزيونية إبحار",
    "sailing television miniseries": "مسلسلات قصيرة تلفزيونية إبحار",
    "sailing television news": "أخبار تلفزيونية إبحار",
    "sailing television programmes": "برامج تلفزيونية إبحار",
    "sailing television programs": "برامج تلفزيونية إبحار",
    "sailing television series": "مسلسلات تلفزيونية إبحار",
    "sailing video games": "ألعاب فيديو إبحار",
    "sailing web series": "مسلسلات ويب إبحار",
    "samurai cinema comics": "قصص مصورة ساموراي",
    "samurai cinema film series": "سلاسل أفلام ساموراي",
    "samurai cinema soap opera": "مسلسلات طويلة ساموراي",
    "samurai cinema television episodes": "حلقات تلفزيونية ساموراي",
    "samurai cinema television films": "أفلام تلفزيونية ساموراي",
    "samurai cinema television miniseries": "مسلسلات قصيرة تلفزيونية ساموراي",
    "samurai cinema television news": "أخبار تلفزيونية ساموراي",
    "samurai cinema television programmes": "برامج تلفزيونية ساموراي",
    "samurai cinema television programs": "برامج تلفزيونية ساموراي",
    "samurai cinema television series": "مسلسلات تلفزيونية ساموراي",
    "samurai cinema video games": "ألعاب فيديو ساموراي",
    "samurai cinema web series": "مسلسلات ويب ساموراي",
    "satire comics": "قصص مصورة هجائية",
    "satire film series": "سلاسل أفلام هجائية",
    "satire soap opera": "مسلسلات طويلة هجائية",
    "satire television episodes": "حلقات تلفزيونية هجائية",
    "satire television films": "أفلام تلفزيونية هجائية",
    "satire television miniseries": "مسلسلات قصيرة تلفزيونية هجائية",
    "satire television news": "أخبار تلفزيونية هجائية",
    "satire television programmes": "برامج تلفزيونية هجائية",
    "satire television programs": "برامج تلفزيونية هجائية",
    "satire television series": "مسلسلات تلفزيونية هجائية",
    "satire video games": "ألعاب فيديو هجائية",
    "satire web series": "مسلسلات ويب هجائية",
    "school comics": "قصص مصورة مدرسية",
    "school film series": "سلاسل أفلام مدرسية",
    "school soap opera": "مسلسلات طويلة مدرسية",
    "school television episodes": "حلقات تلفزيونية مدرسية",
    "school television films": "أفلام تلفزيونية مدرسية",
    "school television miniseries": "مسلسلات قصيرة تلفزيونية مدرسية",
    "school television news": "أخبار تلفزيونية مدرسية",
    "school television programmes": "برامج تلفزيونية مدرسية",
    "school television programs": "برامج تلفزيونية مدرسية",
    "school television series": "مسلسلات تلفزيونية مدرسية",
    "school video games": "ألعاب فيديو مدرسية",
    "school web series": "مسلسلات ويب مدرسية",
    "science comics": "قصص مصورة علمية",
    "science fantasy comics": "قصص مصورة فنتازيا علمية",
    "science fantasy film series": "سلاسل أفلام فنتازيا علمية",
    "science fantasy soap opera": "مسلسلات طويلة فنتازيا علمية",
    "science fantasy television episodes": "حلقات تلفزيونية فنتازيا علمية",
    "science fantasy television films": "أفلام تلفزيونية فنتازيا علمية",
    "science fantasy television miniseries": "مسلسلات قصيرة تلفزيونية فنتازيا علمية",
    "science fantasy television news": "أخبار تلفزيونية فنتازيا علمية",
    "science fantasy television programmes": "برامج تلفزيونية فنتازيا علمية",
    "science fantasy television programs": "برامج تلفزيونية فنتازيا علمية",
    "science fantasy television series": "مسلسلات تلفزيونية فنتازيا علمية",
    "science fantasy video games": "ألعاب فيديو فنتازيا علمية",
    "science fantasy web series": "مسلسلات ويب فنتازيا علمية",
    "science fiction action comics": "قصص مصورة خيال علمي وحركة",
    "science fiction action film series": "سلاسل أفلام خيال علمي وحركة",
    "science fiction action soap opera": "مسلسلات طويلة خيال علمي وحركة",
    "science fiction action television episodes": "حلقات تلفزيونية خيال علمي وحركة",
    "science fiction action television films": "أفلام تلفزيونية خيال علمي وحركة",
    "science fiction action television miniseries": "مسلسلات قصيرة تلفزيونية خيال علمي وحركة",
    "science fiction action television news": "أخبار تلفزيونية خيال علمي وحركة",
    "science fiction action television programmes": "برامج تلفزيونية خيال علمي وحركة",
    "science fiction action television programs": "برامج تلفزيونية خيال علمي وحركة",
    "science fiction action television series": "مسلسلات تلفزيونية خيال علمي وحركة",
    "science fiction action video games": "ألعاب فيديو خيال علمي وحركة",
    "science fiction action web series": "مسلسلات ويب خيال علمي وحركة",
    "science fiction comics": "قصص مصورة خيال علمي",
    "science fiction film series": "سلاسل أفلام خيال علمي",
    "science fiction soap opera": "مسلسلات طويلة خيال علمي",
    "science fiction television episodes": "حلقات تلفزيونية خيال علمي",
    "science fiction television films": "أفلام تلفزيونية خيال علمي",
    "science fiction television miniseries": "مسلسلات قصيرة تلفزيونية خيال علمي",
    "science fiction television news": "أخبار تلفزيونية خيال علمي",
    "science fiction television programmes": "برامج تلفزيونية خيال علمي",
    "science fiction television programs": "برامج تلفزيونية خيال علمي",
    "science fiction television series": "مسلسلات تلفزيونية خيال علمي",
    "science fiction thriller comics": "قصص مصورة إثارة خيال علمي",
    "science fiction thriller film series": "سلاسل أفلام إثارة خيال علمي",
    "science fiction thriller films": "أفلام إثارة خيال علمي",
    "science fiction thriller soap opera": "مسلسلات طويلة إثارة خيال علمي",
    "science fiction thriller television episodes": "حلقات تلفزيونية إثارة خيال علمي",
    "science fiction thriller television films": "أفلام تلفزيونية إثارة خيال علمي",
    "science fiction thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة خيال علمي",
    "science fiction thriller television news": "أخبار تلفزيونية إثارة خيال علمي",
    "science fiction thriller television programmes": "برامج تلفزيونية إثارة خيال علمي",
    "science fiction thriller television programs": "برامج تلفزيونية إثارة خيال علمي",
    "science fiction thriller television series": "مسلسلات تلفزيونية إثارة خيال علمي",
    "science fiction thriller video games": "ألعاب فيديو إثارة خيال علمي",
    "science fiction thriller web series": "مسلسلات ويب إثارة خيال علمي",
    "science fiction video games": "ألعاب فيديو خيال علمي",
    "science fiction web series": "مسلسلات ويب خيال علمي",
    "science film series": "سلاسل أفلام علمية",
    "science soap opera": "مسلسلات طويلة علمية",
    "science television episodes": "حلقات تلفزيونية علمية",
    "science television films": "أفلام تلفزيونية علمية",
    "science television miniseries": "مسلسلات قصيرة تلفزيونية علمية",
    "science television news": "أخبار تلفزيونية علمية",
    "science television programmes": "برامج تلفزيونية علمية",
    "science television programs": "برامج تلفزيونية علمية",
    "science television series": "مسلسلات تلفزيونية علمية",
    "science video games": "ألعاب فيديو علمية",
    "science web series": "مسلسلات ويب علمية",
    "sequel comics": "قصص مصورة متممة",
    "sequel film series": "سلاسل أفلام متممة",
    "sequel soap opera": "مسلسلات طويلة متممة",
    "sequel television episodes": "حلقات تلفزيونية متممة",
    "sequel television films": "أفلام تلفزيونية متممة",
    "sequel television miniseries": "مسلسلات قصيرة تلفزيونية متممة",
    "sequel television news": "أخبار تلفزيونية متممة",
    "sequel television programmes": "برامج تلفزيونية متممة",
    "sequel television programs": "برامج تلفزيونية متممة",
    "sequel television series": "مسلسلات تلفزيونية متممة",
    "sequel video games": "ألعاب فيديو متممة",
    "sequel web series": "مسلسلات ويب متممة",
    "sex comics": "قصص مصورة جنسية",
    "sex film series": "سلاسل أفلام جنسية",
    "sex soap opera": "مسلسلات طويلة جنسية",
    "sex television episodes": "حلقات تلفزيونية جنسية",
    "sex television films": "أفلام تلفزيونية جنسية",
    "sex television miniseries": "مسلسلات قصيرة تلفزيونية جنسية",
    "sex television news": "أخبار تلفزيونية جنسية",
    "sex television programmes": "برامج تلفزيونية جنسية",
    "sex television programs": "برامج تلفزيونية جنسية",
    "sex television series": "مسلسلات تلفزيونية جنسية",
    "sex video games": "ألعاب فيديو جنسية",
    "sex web series": "مسلسلات ويب جنسية",
    "short comics": "قصص مصورة قصيرة",
    "short film series": "سلاسل أفلام قصيرة",
    "short soap opera": "مسلسلات طويلة قصيرة",
    "short television episodes": "حلقات تلفزيونية قصيرة",
    "short television films": "أفلام تلفزيونية قصيرة",
    "short television miniseries": "مسلسلات قصيرة تلفزيونية قصيرة",
    "short television news": "أخبار تلفزيونية قصيرة",
    "short television programmes": "برامج تلفزيونية قصيرة",
    "short television programs": "برامج تلفزيونية قصيرة",
    "short television series": "مسلسلات تلفزيونية قصيرة",
    "short video games": "ألعاب فيديو قصيرة",
    "short web series": "مسلسلات ويب قصيرة",
    "siddy comics": "قصص مصورة أصدقاء",
    "siddy film series": "سلاسل أفلام أصدقاء",
    "siddy soap opera": "مسلسلات طويلة أصدقاء",
    "siddy television episodes": "حلقات تلفزيونية أصدقاء",
    "siddy television films": "أفلام تلفزيونية أصدقاء",
    "siddy television miniseries": "مسلسلات قصيرة تلفزيونية أصدقاء",
    "siddy television news": "أخبار تلفزيونية أصدقاء",
    "siddy television programmes": "برامج تلفزيونية أصدقاء",
    "siddy television programs": "برامج تلفزيونية أصدقاء",
    "siddy television series": "مسلسلات تلفزيونية أصدقاء",
    "siddy video games": "ألعاب فيديو أصدقاء",
    "siddy web series": "مسلسلات ويب أصدقاء",
    "silent comics": "قصص مصورة صامتة",
    "silent film series": "سلاسل أفلام صامتة",
    "silent short comics": "قصص مصورة قصيرة صامته",
    "silent short film series": "سلاسل أفلام قصيرة صامته",
    "silent short soap opera": "مسلسلات طويلة قصيرة صامته",
    "silent short television episodes": "حلقات تلفزيونية قصيرة صامته",
    "silent short television films": "أفلام تلفزيونية قصيرة صامته",
    "silent short television miniseries": "مسلسلات قصيرة تلفزيونية قصيرة صامته",
    "silent short television news": "أخبار تلفزيونية قصيرة صامته",
    "silent short television programmes": "برامج تلفزيونية قصيرة صامته",
    "silent short television programs": "برامج تلفزيونية قصيرة صامته",
    "silent short television series": "مسلسلات تلفزيونية قصيرة صامته",
    "silent short video games": "ألعاب فيديو قصيرة صامته",
    "silent short web series": "مسلسلات ويب قصيرة صامته",
    "silent soap opera": "مسلسلات طويلة صامتة",
    "silent television episodes": "حلقات تلفزيونية صامتة",
    "silent television films": "أفلام تلفزيونية صامتة",
    "silent television miniseries": "مسلسلات قصيرة تلفزيونية صامتة",
    "silent television news": "أخبار تلفزيونية صامتة",
    "silent television programmes": "برامج تلفزيونية صامتة",
    "silent television programs": "برامج تلفزيونية صامتة",
    "silent television series": "مسلسلات تلفزيونية صامتة",
    "silent video games": "ألعاب فيديو صامتة",
    "silent web series": "مسلسلات ويب صامتة",
    "sisiness comics": "قصص مصورة أعمال",
    "sisiness film series": "سلاسل أفلام أعمال",
    "sisiness soap opera": "مسلسلات طويلة أعمال",
    "sisiness television episodes": "حلقات تلفزيونية أعمال",
    "sisiness television films": "أفلام تلفزيونية أعمال",
    "sisiness television miniseries": "مسلسلات قصيرة تلفزيونية أعمال",
    "sisiness television news": "أخبار تلفزيونية أعمال",
    "sisiness television programmes": "برامج تلفزيونية أعمال",
    "sisiness television programs": "برامج تلفزيونية أعمال",
    "sisiness television series": "مسلسلات تلفزيونية أعمال",
    "sisiness video games": "ألعاب فيديو أعمال",
    "sisiness web series": "مسلسلات ويب أعمال",
    "slapstick comics": "قصص مصورة كوميدية تهريجية",
    "slapstick film series": "سلاسل أفلام كوميدية تهريجية",
    "slapstick soap opera": "مسلسلات طويلة كوميدية تهريجية",
    "slapstick television episodes": "حلقات تلفزيونية كوميدية تهريجية",
    "slapstick television films": "أفلام تلفزيونية كوميدية تهريجية",
    "slapstick television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية تهريجية",
    "slapstick television news": "أخبار تلفزيونية كوميدية تهريجية",
    "slapstick television programmes": "برامج تلفزيونية كوميدية تهريجية",
    "slapstick television programs": "برامج تلفزيونية كوميدية تهريجية",
    "slapstick television series": "مسلسلات تلفزيونية كوميدية تهريجية",
    "slapstick video games": "ألعاب فيديو كوميدية تهريجية",
    "slapstick web series": "مسلسلات ويب كوميدية تهريجية",
    "slasher comics": "قصص مصورة تقطيع",
    "slasher film series": "سلاسل أفلام تقطيع",
    "slasher soap opera": "مسلسلات طويلة تقطيع",
    "slasher television episodes": "حلقات تلفزيونية تقطيع",
    "slasher television films": "أفلام تلفزيونية تقطيع",
    "slasher television miniseries": "مسلسلات قصيرة تلفزيونية تقطيع",
    "slasher television news": "أخبار تلفزيونية تقطيع",
    "slasher television programmes": "برامج تلفزيونية تقطيع",
    "slasher television programs": "برامج تلفزيونية تقطيع",
    "slasher television series": "مسلسلات تلفزيونية تقطيع",
    "slasher video games": "ألعاب فيديو تقطيع",
    "slasher web series": "مسلسلات ويب تقطيع",
    "sound comics": "قصص مصورة ناطقة",
    "sound soap opera": "مسلسلات طويلة ناطقة",
    "sound television episodes": "حلقات تلفزيونية ناطقة",
    "sound television films": "أفلام تلفزيونية ناطقة",
    "sound television miniseries": "مسلسلات قصيرة تلفزيونية ناطقة",
    "sound television news": "أخبار تلفزيونية ناطقة",
    "sound television programmes": "برامج تلفزيونية ناطقة",
    "sound television programs": "برامج تلفزيونية ناطقة",
    "sound television series": "مسلسلات تلفزيونية ناطقة",
    "sound video games": "ألعاب فيديو ناطقة",
    "sound web series": "مسلسلات ويب ناطقة",
    "spaghetti western comics": "قصص مصورة سباغيتي وسترن",
    "spaghetti western film series": "سلاسل أفلام سباغيتي وسترن",
    "spaghetti western soap opera": "مسلسلات طويلة سباغيتي وسترن",
    "spaghetti western television episodes": "حلقات تلفزيونية سباغيتي وسترن",
    "spaghetti western television films": "أفلام تلفزيونية سباغيتي وسترن",
    "spaghetti western television miniseries": "مسلسلات قصيرة تلفزيونية سباغيتي وسترن",
    "spaghetti western television news": "أخبار تلفزيونية سباغيتي وسترن",
    "spaghetti western television programmes": "برامج تلفزيونية سباغيتي وسترن",
    "spaghetti western television programs": "برامج تلفزيونية سباغيتي وسترن",
    "spaghetti western television series": "مسلسلات تلفزيونية سباغيتي وسترن",
    "spaghetti western video games": "ألعاب فيديو سباغيتي وسترن",
    "spaghetti western web series": "مسلسلات ويب سباغيتي وسترن",
    "speculative comics": "قصص مصورة تأملية",
    "speculative fiction comics": "قصص مصورة خيالية تأملية",
    "speculative fiction film series": "سلاسل أفلام خيالية تأملية",
    "speculative fiction soap opera": "مسلسلات طويلة خيالية تأملية",
    "speculative fiction television episodes": "حلقات تلفزيونية خيالية تأملية",
    "speculative fiction television films": "أفلام تلفزيونية خيالية تأملية",
    "speculative fiction television miniseries": "مسلسلات قصيرة تلفزيونية خيالية تأملية",
    "speculative fiction television news": "أخبار تلفزيونية خيالية تأملية",
    "speculative fiction television programmes": "برامج تلفزيونية خيالية تأملية",
    "speculative fiction television programs": "برامج تلفزيونية خيالية تأملية",
    "speculative fiction television series": "مسلسلات تلفزيونية خيالية تأملية",
    "speculative fiction video games": "ألعاب فيديو خيالية تأملية",
    "speculative fiction web series": "مسلسلات ويب خيالية تأملية",
    "speculative film series": "سلاسل أفلام تأملية",
    "speculative soap opera": "مسلسلات طويلة تأملية",
    "speculative television episodes": "حلقات تلفزيونية تأملية",
    "speculative television films": "أفلام تلفزيونية تأملية",
    "speculative television miniseries": "مسلسلات قصيرة تلفزيونية تأملية",
    "speculative television news": "أخبار تلفزيونية تأملية",
    "speculative television programmes": "برامج تلفزيونية تأملية",
    "speculative television programs": "برامج تلفزيونية تأملية",
    "speculative television series": "مسلسلات تلفزيونية تأملية",
    "speculative video games": "ألعاب فيديو تأملية",
    "speculative web series": "مسلسلات ويب تأملية",
    "sports comics": "قصص مصورة رياضية",
    "sports film series": "سلاسل أفلام رياضية",
    "sports soap opera": "مسلسلات طويلة رياضية",
    "sports television episodes": "حلقات تلفزيونية رياضية",
    "sports television films": "أفلام تلفزيونية رياضية",
    "sports television miniseries": "مسلسلات قصيرة تلفزيونية رياضية",
    "sports television news": "أخبار تلفزيونية رياضية",
    "sports television programmes": "برامج تلفزيونية رياضية",
    "sports television programs": "برامج تلفزيونية رياضية",
    "sports television series": "مسلسلات تلفزيونية رياضية",
    "sports video games": "ألعاب فيديو رياضية",
    "sports web series": "مسلسلات ويب رياضية",
    "spy comics": "قصص مصورة تجسسية",
    "spy film series": "سلاسل أفلام تجسسية",
    "spy soap opera": "مسلسلات طويلة تجسسية",
    "spy television episodes": "حلقات تلفزيونية تجسسية",
    "spy television films": "أفلام تلفزيونية تجسسية",
    "spy television miniseries": "مسلسلات قصيرة تلفزيونية تجسسية",
    "spy television news": "أخبار تلفزيونية تجسسية",
    "spy television programmes": "برامج تلفزيونية تجسسية",
    "spy television programs": "برامج تلفزيونية تجسسية",
    "spy television series": "مسلسلات تلفزيونية تجسسية",
    "spy video games": "ألعاب فيديو تجسسية",
    "spy web series": "مسلسلات ويب تجسسية",
    "street fighter comics": "قصص مصورة قتال شوارع",
    "street fighter film series": "سلاسل أفلام قتال شوارع",
    "street fighter soap opera": "مسلسلات طويلة قتال شوارع",
    "street fighter television episodes": "حلقات تلفزيونية قتال شوارع",
    "street fighter television films": "أفلام تلفزيونية قتال شوارع",
    "street fighter television miniseries": "مسلسلات قصيرة تلفزيونية قتال شوارع",
    "street fighter television news": "أخبار تلفزيونية قتال شوارع",
    "street fighter television programmes": "برامج تلفزيونية قتال شوارع",
    "street fighter television programs": "برامج تلفزيونية قتال شوارع",
    "street fighter television series": "مسلسلات تلفزيونية قتال شوارع",
    "street fighter video games": "ألعاب فيديو قتال شوارع",
    "street fighter web series": "مسلسلات ويب قتال شوارع",
    "student comics": "قصص مصورة طلاب",
    "student film series": "سلاسل أفلام طلاب",
    "student soap opera": "مسلسلات طويلة طلاب",
    "student television episodes": "حلقات تلفزيونية طلاب",
    "student television films": "أفلام تلفزيونية طلاب",
    "student television miniseries": "مسلسلات قصيرة تلفزيونية طلاب",
    "student television news": "أخبار تلفزيونية طلاب",
    "student television programmes": "برامج تلفزيونية طلاب",
    "student television programs": "برامج تلفزيونية طلاب",
    "student television series": "مسلسلات تلفزيونية طلاب",
    "student video games": "ألعاب فيديو طلاب",
    "student web series": "مسلسلات ويب طلاب",
    "submarines comics": "قصص مصورة غواصات",
    "submarines film series": "سلاسل أفلام غواصات",
    "submarines soap opera": "مسلسلات طويلة غواصات",
    "submarines television episodes": "حلقات تلفزيونية غواصات",
    "submarines television films": "أفلام تلفزيونية غواصات",
    "submarines television miniseries": "مسلسلات قصيرة تلفزيونية غواصات",
    "submarines television news": "أخبار تلفزيونية غواصات",
    "submarines television programmes": "برامج تلفزيونية غواصات",
    "submarines television programs": "برامج تلفزيونية غواصات",
    "submarines television series": "مسلسلات تلفزيونية غواصات",
    "submarines video games": "ألعاب فيديو غواصات",
    "submarines web series": "مسلسلات ويب غواصات",
    "super robot comics": "قصص مصورة آلية خارقة",
    "super robot film series": "سلاسل أفلام آلية خارقة",
    "super robot soap opera": "مسلسلات طويلة آلية خارقة",
    "super robot television episodes": "حلقات تلفزيونية آلية خارقة",
    "super robot television films": "أفلام تلفزيونية آلية خارقة",
    "super robot television miniseries": "مسلسلات قصيرة تلفزيونية آلية خارقة",
    "super robot television news": "أخبار تلفزيونية آلية خارقة",
    "super robot television programmes": "برامج تلفزيونية آلية خارقة",
    "super robot television programs": "برامج تلفزيونية آلية خارقة",
    "super robot television series": "مسلسلات تلفزيونية آلية خارقة",
    "super robot video games": "ألعاب فيديو آلية خارقة",
    "super robot web series": "مسلسلات ويب آلية خارقة",
    "supernatural comics": "قصص مصورة خارقة للطبيعة",
    "supernatural drama comics": "قصص مصورة دراما خارقة للطبيعة",
    "supernatural drama film series": "سلاسل أفلام دراما خارقة للطبيعة",
    "supernatural drama soap opera": "مسلسلات طويلة دراما خارقة للطبيعة",
    "supernatural drama television episodes": "حلقات تلفزيونية دراما خارقة للطبيعة",
    "supernatural drama television films": "أفلام تلفزيونية دراما خارقة للطبيعة",
    "supernatural drama television miniseries": "مسلسلات قصيرة تلفزيونية دراما خارقة للطبيعة",
    "supernatural drama television news": "أخبار تلفزيونية دراما خارقة للطبيعة",
    "supernatural drama television programmes": "برامج تلفزيونية دراما خارقة للطبيعة",
    "supernatural drama television programs": "برامج تلفزيونية دراما خارقة للطبيعة",
    "supernatural drama television series": "مسلسلات تلفزيونية دراما خارقة للطبيعة",
    "supernatural drama video games": "ألعاب فيديو دراما خارقة للطبيعة",
    "supernatural drama web series": "مسلسلات ويب دراما خارقة للطبيعة",
    "supernatural film series": "سلاسل أفلام خارقة للطبيعة",
    "supernatural soap opera": "مسلسلات طويلة خارقة للطبيعة",
    "supernatural television episodes": "حلقات تلفزيونية خارقة للطبيعة",
    "supernatural television films": "أفلام تلفزيونية خارقة للطبيعة",
    "supernatural television miniseries": "مسلسلات قصيرة تلفزيونية خارقة للطبيعة",
    "supernatural television news": "أخبار تلفزيونية خارقة للطبيعة",
    "supernatural television programmes": "برامج تلفزيونية خارقة للطبيعة",
    "supernatural television programs": "برامج تلفزيونية خارقة للطبيعة",
    "supernatural television series": "مسلسلات تلفزيونية خارقة للطبيعة",
    "supernatural video games": "ألعاب فيديو خارقة للطبيعة",
    "supernatural web series": "مسلسلات ويب خارقة للطبيعة",
    "survival comics": "قصص مصورة البقاء على قيد الحياة",
    "survival film series": "سلاسل أفلام البقاء على قيد الحياة",
    "survival soap opera": "مسلسلات طويلة البقاء على قيد الحياة",
    "survival television episodes": "حلقات تلفزيونية البقاء على قيد الحياة",
    "survival television films": "أفلام تلفزيونية البقاء على قيد الحياة",
    "survival television miniseries": "مسلسلات قصيرة تلفزيونية البقاء على قيد الحياة",
    "survival television news": "أخبار تلفزيونية البقاء على قيد الحياة",
    "survival television programmes": "برامج تلفزيونية البقاء على قيد الحياة",
    "survival television programs": "برامج تلفزيونية البقاء على قيد الحياة",
    "survival television series": "مسلسلات تلفزيونية البقاء على قيد الحياة",
    "survival video games": "ألعاب فيديو البقاء على قيد الحياة",
    "survival web series": "مسلسلات ويب البقاء على قيد الحياة",
    "teen comics": "قصص مصورة مراهقة",
    "teen film series": "سلاسل أفلام مراهقة",
    "teen soap opera": "مسلسلات طويلة مراهقة",
    "teen television episodes": "حلقات تلفزيونية مراهقة",
    "teen television films": "أفلام تلفزيونية مراهقة",
    "teen television miniseries": "مسلسلات قصيرة تلفزيونية مراهقة",
    "teen television news": "أخبار تلفزيونية مراهقة",
    "teen television programmes": "برامج تلفزيونية مراهقة",
    "teen television programs": "برامج تلفزيونية مراهقة",
    "teen television series": "مسلسلات تلفزيونية مراهقة",
    "teen video games": "ألعاب فيديو مراهقة",
    "teen web series": "مسلسلات ويب مراهقة",
    "thriller comics": "قصص مصورة إثارة",
    "thriller film series": "سلاسل أفلام إثارة",
    "thriller films": "أفلام إثارة",
    "thriller soap opera": "مسلسلات طويلة إثارة",
    "thriller television episodes": "حلقات تلفزيونية إثارة",
    "thriller television films": "أفلام تلفزيونية إثارة",
    "thriller television miniseries": "مسلسلات قصيرة تلفزيونية إثارة",
    "thriller television news": "أخبار تلفزيونية إثارة",
    "thriller television programmes": "برامج تلفزيونية إثارة",
    "thriller television programs": "برامج تلفزيونية إثارة",
    "thriller television series": "مسلسلات تلفزيونية إثارة",
    "thriller video games": "ألعاب فيديو إثارة",
    "thriller web series": "مسلسلات ويب إثارة",
    "tragicomedy comics": "قصص مصورة تراجيدية كوميدية",
    "tragicomedy film series": "سلاسل أفلام تراجيدية كوميدية",
    "tragicomedy soap opera": "مسلسلات طويلة تراجيدية كوميدية",
    "tragicomedy television episodes": "حلقات تلفزيونية تراجيدية كوميدية",
    "tragicomedy television films": "أفلام تلفزيونية تراجيدية كوميدية",
    "tragicomedy television miniseries": "مسلسلات قصيرة تلفزيونية تراجيدية كوميدية",
    "tragicomedy television news": "أخبار تلفزيونية تراجيدية كوميدية",
    "tragicomedy television programmes": "برامج تلفزيونية تراجيدية كوميدية",
    "tragicomedy television programs": "برامج تلفزيونية تراجيدية كوميدية",
    "tragicomedy television series": "مسلسلات تلفزيونية تراجيدية كوميدية",
    "tragicomedy video games": "ألعاب فيديو تراجيدية كوميدية",
    "tragicomedy web series": "مسلسلات ويب تراجيدية كوميدية",
    "travel documentary comics": "قصص مصورة وثائقي سفر",
    "travel documentary film series": "سلاسل أفلام وثائقي سفر",
    "travel documentary soap opera": "مسلسلات طويلة وثائقي سفر",
    "travel documentary television episodes": "حلقات تلفزيونية وثائقي سفر",
    "travel documentary television films": "أفلام تلفزيونية وثائقي سفر",
    "travel documentary television miniseries": "مسلسلات قصيرة تلفزيونية وثائقي سفر",
    "travel documentary television news": "أخبار تلفزيونية وثائقي سفر",
    "travel documentary television programmes": "برامج تلفزيونية وثائقي سفر",
    "travel documentary television programs": "برامج تلفزيونية وثائقي سفر",
    "travel documentary television series": "مسلسلات تلفزيونية وثائقي سفر",
    "travel documentary video games": "ألعاب فيديو وثائقي سفر",
    "travel documentary web series": "مسلسلات ويب وثائقي سفر",
    "treasure hunt comics": "قصص مصورة صيد كنوز",
    "treasure hunt film series": "سلاسل أفلام صيد كنوز",
    "treasure hunt soap opera": "مسلسلات طويلة صيد كنوز",
    "treasure hunt television episodes": "حلقات تلفزيونية صيد كنوز",
    "treasure hunt television films": "أفلام تلفزيونية صيد كنوز",
    "treasure hunt television miniseries": "مسلسلات قصيرة تلفزيونية صيد كنوز",
    "treasure hunt television news": "أخبار تلفزيونية صيد كنوز",
    "treasure hunt television programmes": "برامج تلفزيونية صيد كنوز",
    "treasure hunt television programs": "برامج تلفزيونية صيد كنوز",
    "treasure hunt television series": "مسلسلات تلفزيونية صيد كنوز",
    "treasure hunt video games": "ألعاب فيديو صيد كنوز",
    "treasure hunt web series": "مسلسلات ويب صيد كنوز",
    "unfinished comics": "قصص مصورة ناقصة",
    "unfinished film series": "سلاسل أفلام ناقصة",
    "unfinished soap opera": "مسلسلات طويلة ناقصة",
    "unfinished television episodes": "حلقات تلفزيونية ناقصة",
    "unfinished television films": "أفلام تلفزيونية ناقصة",
    "unfinished television miniseries": "مسلسلات قصيرة تلفزيونية ناقصة",
    "unfinished television news": "أخبار تلفزيونية ناقصة",
    "unfinished television programmes": "برامج تلفزيونية ناقصة",
    "unfinished television programs": "برامج تلفزيونية ناقصة",
    "unfinished television series": "مسلسلات تلفزيونية ناقصة",
    "unfinished video games": "ألعاب فيديو ناقصة",
    "unfinished web series": "مسلسلات ويب ناقصة",
    "upcoming comics": "قصص مصورة قادمة",
    "upcoming film series": "سلاسل أفلام قادمة",
    "upcoming soap opera": "مسلسلات طويلة قادمة",
    "upcoming television episodes": "حلقات تلفزيونية قادمة",
    "upcoming television films": "أفلام تلفزيونية قادمة",
    "upcoming television miniseries": "مسلسلات قصيرة تلفزيونية قادمة",
    "upcoming television news": "أخبار تلفزيونية قادمة",
    "upcoming television programmes": "برامج تلفزيونية قادمة",
    "upcoming television programs": "برامج تلفزيونية قادمة",
    "upcoming television series": "مسلسلات تلفزيونية قادمة",
    "upcoming video games": "ألعاب فيديو قادمة",
    "upcoming web series": "مسلسلات ويب قادمة",
    "vampire comics": "قصص مصورة مصاصي دماء",
    "vampire film series": "سلاسل أفلام مصاصي دماء",
    "vampire soap opera": "مسلسلات طويلة مصاصي دماء",
    "vampire television episodes": "حلقات تلفزيونية مصاصي دماء",
    "vampire television films": "أفلام تلفزيونية مصاصي دماء",
    "vampire television miniseries": "مسلسلات قصيرة تلفزيونية مصاصي دماء",
    "vampire television news": "أخبار تلفزيونية مصاصي دماء",
    "vampire television programmes": "برامج تلفزيونية مصاصي دماء",
    "vampire television programs": "برامج تلفزيونية مصاصي دماء",
    "vampire television series": "مسلسلات تلفزيونية مصاصي دماء",
    "vampire video games": "ألعاب فيديو مصاصي دماء",
    "vampire web series": "مسلسلات ويب مصاصي دماء",
    "war comics": "قصص مصورة حربية",
    "war film series": "سلاسل أفلام حربية",
    "war films": "أفلام حربية",
    "war soap opera": "مسلسلات طويلة حربية",
    "war television episodes": "حلقات تلفزيونية حربية",
    "war television films": "أفلام تلفزيونية حربية",
    "war television miniseries": "مسلسلات قصيرة تلفزيونية حربية",
    "war television news": "أخبار تلفزيونية حربية",
    "war television programmes": "برامج تلفزيونية حربية",
    "war television programs": "برامج تلفزيونية حربية",
    "war television series": "مسلسلات تلفزيونية حربية",
    "war video games": "ألعاب فيديو حربية",
    "war web series": "مسلسلات ويب حربية",
    "werewolve comics": "قصص مصورة مستذئب",
    "werewolve film series": "سلاسل أفلام مستذئب",
    "werewolve soap opera": "مسلسلات طويلة مستذئب",
    "werewolve television episodes": "حلقات تلفزيونية مستذئب",
    "werewolve television films": "أفلام تلفزيونية مستذئب",
    "werewolve television miniseries": "مسلسلات قصيرة تلفزيونية مستذئب",
    "werewolve television news": "أخبار تلفزيونية مستذئب",
    "werewolve television programmes": "برامج تلفزيونية مستذئب",
    "werewolve television programs": "برامج تلفزيونية مستذئب",
    "werewolve television series": "مسلسلات تلفزيونية مستذئب",
    "werewolve video games": "ألعاب فيديو مستذئب",
    "werewolve web series": "مسلسلات ويب مستذئب",
    "western comics": "قصص مصورة غرب أمريكية",
    "western film series": "سلاسل أفلام غرب أمريكية",
    "western soap opera": "مسلسلات طويلة غرب أمريكية",
    "western television episodes": "حلقات تلفزيونية غرب أمريكية",
    "western television films": "أفلام تلفزيونية غرب أمريكية",
    "western television miniseries": "مسلسلات قصيرة تلفزيونية غرب أمريكية",
    "western television news": "أخبار تلفزيونية غرب أمريكية",
    "western television programmes": "برامج تلفزيونية غرب أمريكية",
    "western television programs": "برامج تلفزيونية غرب أمريكية",
    "western television series": "مسلسلات تلفزيونية غرب أمريكية",
    "western video games": "ألعاب فيديو غرب أمريكية",
    "western web series": "مسلسلات ويب غرب أمريكية",
    "woman's comics": "قصص مصورة نسائية",
    "woman's film series": "سلاسل أفلام نسائية",
    "woman's soap opera": "مسلسلات طويلة نسائية",
    "woman's television episodes": "حلقات تلفزيونية نسائية",
    "woman's television films": "أفلام تلفزيونية نسائية",
    "woman's television miniseries": "مسلسلات قصيرة تلفزيونية نسائية",
    "woman's television news": "أخبار تلفزيونية نسائية",
    "woman's television programmes": "برامج تلفزيونية نسائية",
    "woman's television programs": "برامج تلفزيونية نسائية",
    "woman's television series": "مسلسلات تلفزيونية نسائية",
    "woman's video games": "ألعاب فيديو نسائية",
    "woman's web series": "مسلسلات ويب نسائية",
    "zombie comedy comics": "قصص مصورة كوميدية الزومبي",
    "zombie comedy film series": "سلاسل أفلام كوميدية الزومبي",
    "zombie comedy soap opera": "مسلسلات طويلة كوميدية الزومبي",
    "zombie comedy television episodes": "حلقات تلفزيونية كوميدية الزومبي",
    "zombie comedy television films": "أفلام تلفزيونية كوميدية الزومبي",
    "zombie comedy television miniseries": "مسلسلات قصيرة تلفزيونية كوميدية الزومبي",
    "zombie comedy television news": "أخبار تلفزيونية كوميدية الزومبي",
    "zombie comedy television programmes": "برامج تلفزيونية كوميدية الزومبي",
    "zombie comedy television programs": "برامج تلفزيونية كوميدية الزومبي",
    "zombie comedy television series": "مسلسلات تلفزيونية كوميدية الزومبي",
    "zombie comedy video games": "ألعاب فيديو كوميدية الزومبي",
    "zombie comedy web series": "مسلسلات ويب كوميدية الزومبي",
    "zombie comics": "قصص مصورة زومبي",
    "zombie film series": "سلاسل أفلام زومبي",
    "zombie soap opera": "مسلسلات طويلة زومبي",
    "zombie television episodes": "حلقات تلفزيونية زومبي",
    "zombie television films": "أفلام تلفزيونية زومبي",
    "zombie television miniseries": "مسلسلات قصيرة تلفزيونية زومبي",
    "zombie television news": "أخبار تلفزيونية زومبي",
    "zombie television programmes": "برامج تلفزيونية زومبي",
    "zombie television programs": "برامج تلفزيونية زومبي",
    "zombie television series": "مسلسلات تلفزيونية زومبي",
    "zombie video games": "ألعاب فيديو زومبي",
    "zombie web series": "مسلسلات ويب زومبي",
}


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_Films(category: str, expected: str) -> None:
    label = Films(category)
    assert label == expected


test_data4 = test_data2 | test_data

to_test = [
    ("test_Films", test_data4, Films),
    ("test_Films_tyty", test_data4, _get_films_key_tyty_new),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_resolve_films_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
